/****************************************************************************
** Meta object code from reading C++ file 'kalarmapp.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/kalarmapp.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kalarmapp.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9KAlarmAppE_t {};
} // unnamed namespace

template <> constexpr inline auto KAlarmApp::qt_create_metaobjectdata<qt_meta_tag_ZN9KAlarmAppE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KAlarmApp",
        "setExitValue",
        "",
        "trayIconToggled",
        "alarmEnabledToggled",
        "audioPlaying",
        "spreadWindowsToggled",
        "execAlarmSuccess",
        "activateByDBus",
        "args",
        "workingDirectory",
        "processQueue",
        "setAlarmsEnabled",
        "purgeNewArchivedDefault",
        "Resource",
        "atLoginEventAdded",
        "KAlarmCal::KAEvent",
        "notifyAudioStopped",
        "stopAudio",
        "spreadWindows",
        "emailSent",
        "MailSend::JobData",
        "errmsgs",
        "copyerr",
        "quitFatal",
        "checkNextDueAlarm",
        "slotShowInSystemTrayChanged",
        "changeStartOfDay",
        "slotWorkTimeChanged",
        "start",
        "end",
        "QBitArray",
        "days",
        "slotHolidaysChanged",
        "KAlarmCal::Holidays",
        "slotFeb29TypeChanged",
        "KAlarmApp::Feb29Type",
        "slotResourcesTimeout",
        "slotResourcesCreated",
        "slotEditAlarmById",
        "promptArchivedCalendar",
        "slotMessageFontChanged",
        "QFont",
        "setArchivePurgeDays",
        "slotResourceAdded",
        "slotResourcePopulated",
        "slotPurge",
        "slotCommandExited",
        "ShellProcess*",
        "slotFDOPropertiesChanged",
        "interface",
        "QVariantMap",
        "changedProperties",
        "invalidatedProperties"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'setExitValue'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'trayIconToggled'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alarmEnabledToggled'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'audioPlaying'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'spreadWindowsToggled'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'execAlarmSuccess'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activateByDBus'
        QtMocHelpers::SlotData<void(const QStringList &, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'processQueue'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setAlarmsEnabled'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'purgeNewArchivedDefault'
        QtMocHelpers::SlotData<void(const Resource &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'atLoginEventAdded'
        QtMocHelpers::SlotData<void(const KAlarmCal::KAEvent &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'notifyAudioStopped'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopAudio'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'spreadWindows'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'emailSent'
        QtMocHelpers::SlotData<void(const MailSend::JobData &, const QStringList &, bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 2 }, { QMetaType::QStringList, 22 }, { QMetaType::Bool, 23 },
        }}),
        // Slot 'emailSent'
        QtMocHelpers::SlotData<void(const MailSend::JobData &, const QStringList &)>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 21, 2 }, { QMetaType::QStringList, 22 },
        }}),
        // Slot 'quitFatal'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkNextDueAlarm'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowInSystemTrayChanged'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeStartOfDay'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotWorkTimeChanged'
        QtMocHelpers::SlotData<void(const QTime &, const QTime &, const QBitArray &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QTime, 29 }, { QMetaType::QTime, 30 }, { 0x80000000 | 31, 32 },
        }}),
        // Slot 'slotHolidaysChanged'
        QtMocHelpers::SlotData<void(const KAlarmCal::Holidays &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 34, 2 },
        }}),
        // Slot 'slotFeb29TypeChanged'
        QtMocHelpers::SlotData<void(KAlarmApp::Feb29Type)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 2 },
        }}),
        // Slot 'slotResourcesTimeout'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResourcesCreated'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditAlarmById'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'promptArchivedCalendar'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMessageFontChanged'
        QtMocHelpers::SlotData<void(const QFont &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 2 },
        }}),
        // Slot 'setArchivePurgeDays'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResourceAdded'
        QtMocHelpers::SlotData<void(const Resource &)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'slotResourcePopulated'
        QtMocHelpers::SlotData<void(const Resource &)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'slotPurge'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCommandExited'
        QtMocHelpers::SlotData<void(ShellProcess *)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 48, 2 },
        }}),
        // Slot 'slotFDOPropertiesChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, const QStringList &)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 50 }, { 0x80000000 | 51, 52 }, { QMetaType::QStringList, 53 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KAlarmApp, qt_meta_tag_ZN9KAlarmAppE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KAlarmApp::staticMetaObject = { {
    QMetaObject::SuperData::link<QApplication::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KAlarmAppE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KAlarmAppE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9KAlarmAppE_t>.metaTypes,
    nullptr
} };

void KAlarmApp::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KAlarmApp *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setExitValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->trayIconToggled(); break;
        case 2: _t->alarmEnabledToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->audioPlaying((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->spreadWindowsToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->execAlarmSuccess(); break;
        case 6: _t->activateByDBus((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->processQueue(); break;
        case 8: _t->setAlarmsEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->purgeNewArchivedDefault((*reinterpret_cast<std::add_pointer_t<Resource>>(_a[1]))); break;
        case 10: _t->atLoginEventAdded((*reinterpret_cast<std::add_pointer_t<KAlarmCal::KAEvent>>(_a[1]))); break;
        case 11: _t->notifyAudioStopped(); break;
        case 12: _t->stopAudio(); break;
        case 13: _t->spreadWindows((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->emailSent((*reinterpret_cast<std::add_pointer_t<MailSend::JobData>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 15: _t->emailSent((*reinterpret_cast<std::add_pointer_t<MailSend::JobData>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 16: _t->quitFatal(); break;
        case 17: _t->checkNextDueAlarm(); break;
        case 18: _t->slotShowInSystemTrayChanged(); break;
        case 19: _t->changeStartOfDay(); break;
        case 20: _t->slotWorkTimeChanged((*reinterpret_cast<std::add_pointer_t<QTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QTime>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QBitArray>>(_a[3]))); break;
        case 21: _t->slotHolidaysChanged((*reinterpret_cast<std::add_pointer_t<KAlarmCal::Holidays>>(_a[1]))); break;
        case 22: _t->slotFeb29TypeChanged((*reinterpret_cast<std::add_pointer_t<KAlarmApp::Feb29Type>>(_a[1]))); break;
        case 23: _t->slotResourcesTimeout(); break;
        case 24: _t->slotResourcesCreated(); break;
        case 25: _t->slotEditAlarmById(); break;
        case 26: _t->promptArchivedCalendar(); break;
        case 27: _t->slotMessageFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 28: _t->setArchivePurgeDays(); break;
        case 29: _t->slotResourceAdded((*reinterpret_cast<std::add_pointer_t<Resource>>(_a[1]))); break;
        case 30: _t->slotResourcePopulated((*reinterpret_cast<std::add_pointer_t<Resource>>(_a[1]))); break;
        case 31: _t->slotPurge(); break;
        case 32: _t->slotCommandExited((*reinterpret_cast<std::add_pointer_t<ShellProcess*>>(_a[1]))); break;
        case 33: _t->slotFDOPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KAlarmCal::KAEvent >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KAlarmApp::*)(int )>(_a, &KAlarmApp::setExitValue, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAlarmApp::*)()>(_a, &KAlarmApp::trayIconToggled, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAlarmApp::*)(bool )>(_a, &KAlarmApp::alarmEnabledToggled, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAlarmApp::*)(bool )>(_a, &KAlarmApp::audioPlaying, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAlarmApp::*)(bool )>(_a, &KAlarmApp::spreadWindowsToggled, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAlarmApp::*)()>(_a, &KAlarmApp::execAlarmSuccess, 5))
            return;
    }
}

const QMetaObject *KAlarmApp::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KAlarmApp::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KAlarmAppE_t>.strings))
        return static_cast<void*>(this);
    return QApplication::qt_metacast(_clname);
}

int KAlarmApp::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QApplication::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    return _id;
}

// SIGNAL 0
void KAlarmApp::setExitValue(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KAlarmApp::trayIconToggled()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KAlarmApp::alarmEnabledToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KAlarmApp::audioPlaying(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KAlarmApp::spreadWindowsToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KAlarmApp::execAlarmSuccess()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
