/****************************************************************************
** Meta object code from reading C++ file 'sendakonadimail.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kalarm-26.04.0/src/akonadiplugin/sendakonadimail.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sendakonadimail.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SendAkonadiMailE_t {};
} // unnamed namespace

template <> constexpr inline auto SendAkonadiMail::qt_create_metaobjectdata<qt_meta_tag_ZN15SendAkonadiMailE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SendAkonadiMail",
        "queued",
        "",
        "KAlarmCal::KAEvent",
        "sent",
        "MailSend::JobData",
        "errmsgs",
        "sendError",
        "slotEmailSent",
        "KJob*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'queued'
        QtMocHelpers::SignalData<void(const KAlarmCal::KAEvent &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'sent'
        QtMocHelpers::SignalData<void(const MailSend::JobData &, const QStringList &, bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 }, { QMetaType::QStringList, 6 }, { QMetaType::Bool, 7 },
        }}),
        // Slot 'slotEmailSent'
        QtMocHelpers::SlotData<void(KJob *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SendAkonadiMail, qt_meta_tag_ZN15SendAkonadiMailE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SendAkonadiMail::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SendAkonadiMailE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SendAkonadiMailE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SendAkonadiMailE_t>.metaTypes,
    nullptr
} };

void SendAkonadiMail::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SendAkonadiMail *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->queued((*reinterpret_cast<std::add_pointer_t<KAlarmCal::KAEvent>>(_a[1]))); break;
        case 1: _t->sent((*reinterpret_cast<std::add_pointer_t<MailSend::JobData>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 2: _t->slotEmailSent((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KAlarmCal::KAEvent >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SendAkonadiMail::*)(const KAlarmCal::KAEvent & )>(_a, &SendAkonadiMail::queued, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SendAkonadiMail::*)(const MailSend::JobData & , const QStringList & , bool )>(_a, &SendAkonadiMail::sent, 1))
            return;
    }
}

const QMetaObject *SendAkonadiMail::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SendAkonadiMail::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SendAkonadiMailE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SendAkonadiMail::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void SendAkonadiMail::queued(const KAlarmCal::KAEvent & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SendAkonadiMail::sent(const MailSend::JobData & _t1, const QStringList & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
