/****************************************************************************
** Meta object code from reading C++ file 'akonadiresourcemigrator.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kalarm-26.04.0/src/akonadiplugin/akonadiresourcemigrator.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'akonadiresourcemigrator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23AkonadiResourceMigratorE_t {};
} // unnamed namespace

template <> constexpr inline auto AkonadiResourceMigrator::qt_create_metaobjectdata<qt_meta_tag_ZN23AkonadiResourceMigratorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AkonadiResourceMigrator",
        "migrationComplete",
        "",
        "migrated",
        "fileResource",
        "resourceName",
        "QUrl",
        "location",
        "KAlarmCal::CalEvent::Types",
        "alarmTypes",
        "displayName",
        "QColor",
        "backgroundColour",
        "enabledTypes",
        "standardTypes",
        "readOnly",
        "dirResource",
        "path",
        "checkServer",
        "Akonadi::ServerManager::State",
        "collectionFetchResult",
        "KJob*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'migrationComplete'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'fileResource'
        QtMocHelpers::SignalData<void(const QString &, const QUrl &, KAlarmCal::CalEvent::Types, const QString &, const QColor &, KAlarmCal::CalEvent::Types, KAlarmCal::CalEvent::Types, bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { QMetaType::QString, 10 },
            { 0x80000000 | 11, 12 }, { 0x80000000 | 8, 13 }, { 0x80000000 | 8, 14 }, { QMetaType::Bool, 15 },
        }}),
        // Signal 'dirResource'
        QtMocHelpers::SignalData<void(const QString &, const QString &, KAlarmCal::CalEvent::Types, const QString &, const QColor &, KAlarmCal::CalEvent::Types, KAlarmCal::CalEvent::Types, bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 17 }, { 0x80000000 | 8, 9 }, { QMetaType::QString, 10 },
            { 0x80000000 | 11, 12 }, { 0x80000000 | 8, 13 }, { 0x80000000 | 8, 14 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'checkServer'
        QtMocHelpers::SlotData<void(Akonadi::ServerManager::State)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Slot 'collectionFetchResult'
        QtMocHelpers::SlotData<void(KJob *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AkonadiResourceMigrator, qt_meta_tag_ZN23AkonadiResourceMigratorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AkonadiResourceMigrator::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AkonadiResourceMigratorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AkonadiResourceMigratorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23AkonadiResourceMigratorE_t>.metaTypes,
    nullptr
} };

void AkonadiResourceMigrator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AkonadiResourceMigrator *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->migrationComplete((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->fileResource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KAlarmCal::CalEvent::Types>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KAlarmCal::CalEvent::Types>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<KAlarmCal::CalEvent::Types>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8]))); break;
        case 2: _t->dirResource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KAlarmCal::CalEvent::Types>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KAlarmCal::CalEvent::Types>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<KAlarmCal::CalEvent::Types>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8]))); break;
        case 3: _t->checkServer((*reinterpret_cast<std::add_pointer_t<Akonadi::ServerManager::State>>(_a[1]))); break;
        case 4: _t->collectionFetchResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::ServerManager::State >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AkonadiResourceMigrator::*)(bool )>(_a, &AkonadiResourceMigrator::migrationComplete, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AkonadiResourceMigrator::*)(const QString & , const QUrl & , KAlarmCal::CalEvent::Types , const QString & , const QColor & , KAlarmCal::CalEvent::Types , KAlarmCal::CalEvent::Types , bool )>(_a, &AkonadiResourceMigrator::fileResource, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AkonadiResourceMigrator::*)(const QString & , const QString & , KAlarmCal::CalEvent::Types , const QString & , const QColor & , KAlarmCal::CalEvent::Types , KAlarmCal::CalEvent::Types , bool )>(_a, &AkonadiResourceMigrator::dirResource, 2))
            return;
    }
}

const QMetaObject *AkonadiResourceMigrator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AkonadiResourceMigrator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AkonadiResourceMigratorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AkonadiResourceMigrator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void AkonadiResourceMigrator::migrationComplete(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AkonadiResourceMigrator::fileResource(const QString & _t1, const QUrl & _t2, KAlarmCal::CalEvent::Types _t3, const QString & _t4, const QColor & _t5, KAlarmCal::CalEvent::Types _t6, KAlarmCal::CalEvent::Types _t7, bool _t8)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8);
}

// SIGNAL 2
void AkonadiResourceMigrator::dirResource(const QString & _t1, const QString & _t2, KAlarmCal::CalEvent::Types _t3, const QString & _t4, const QColor & _t5, KAlarmCal::CalEvent::Types _t6, KAlarmCal::CalEvent::Types _t7, bool _t8)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8);
}
QT_WARNING_POP
