/********************************************************************************
** Form generated from reading UI file 'dirresourceimportdialog_type.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIRRESOURCEIMPORTDIALOG_TYPE_H
#define UI_DIRRESOURCEIMPORTDIALOG_TYPE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_DirResourceImportTypeWidget
{
public:
    QGridLayout *grid;
    QRadioButton *mergeRadio;
    QComboBox *mergeResource;
    QSpacerItem *spacer1;
    QRadioButton *newRadio;
    QGridLayout *newGrid;
    QLabel *pathLabel;
    KUrlRequester *pathRequester;
    QLabel *statusLabel;
    QLabel *nameLabel;
    KLineEdit *nameText;
    QSpacerItem *spacer2;
    QRadioButton *noRadio;
    QSpacerItem *spacer3;
    QButtonGroup *optionGroup;

    void setupUi(QWidget *DirResourceImportTypeWidget)
    {
        if (DirResourceImportTypeWidget->objectName().isEmpty())
            DirResourceImportTypeWidget->setObjectName("DirResourceImportTypeWidget");
        grid = new QGridLayout(DirResourceImportTypeWidget);
        grid->setObjectName("grid");
        mergeRadio = new QRadioButton(DirResourceImportTypeWidget);
        optionGroup = new QButtonGroup(DirResourceImportTypeWidget);
        optionGroup->setObjectName("optionGroup");
        optionGroup->addButton(mergeRadio);
        mergeRadio->setObjectName("mergeRadio");
        mergeRadio->setChecked(true);

        grid->addWidget(mergeRadio, 0, 0, 1, 2);

        mergeResource = new QComboBox(DirResourceImportTypeWidget);
        mergeResource->setObjectName("mergeResource");

        grid->addWidget(mergeResource, 1, 1, 1, 1);

        spacer1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        grid->addItem(spacer1, 2, 1, 1, 1);

        newRadio = new QRadioButton(DirResourceImportTypeWidget);
        optionGroup->addButton(newRadio);
        newRadio->setObjectName("newRadio");
        newRadio->setChecked(false);

        grid->addWidget(newRadio, 3, 0, 1, 2);

        newGrid = new QGridLayout();
        newGrid->setObjectName("newGrid");
        pathLabel = new QLabel(DirResourceImportTypeWidget);
        pathLabel->setObjectName("pathLabel");

        newGrid->addWidget(pathLabel, 0, 0, 1, 1);

        pathRequester = new KUrlRequester(DirResourceImportTypeWidget);
        pathRequester->setObjectName("pathRequester");

        newGrid->addWidget(pathRequester, 0, 1, 1, 1);

        statusLabel = new QLabel(DirResourceImportTypeWidget);
        statusLabel->setObjectName("statusLabel");
        QFont font;
        font.setBold(true);
        statusLabel->setFont(font);
        statusLabel->setText(QString::fromUtf8("Status:"));

        newGrid->addWidget(statusLabel, 1, 0, 1, 2);

        nameLabel = new QLabel(DirResourceImportTypeWidget);
        nameLabel->setObjectName("nameLabel");

        newGrid->addWidget(nameLabel, 2, 0, 1, 1);

        nameText = new KLineEdit(DirResourceImportTypeWidget);
        nameText->setObjectName("nameText");

        newGrid->addWidget(nameText, 2, 1, 1, 1);


        grid->addLayout(newGrid, 4, 1, 1, 1);

        spacer2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        grid->addItem(spacer2, 5, 1, 1, 1);

        noRadio = new QRadioButton(DirResourceImportTypeWidget);
        optionGroup->addButton(noRadio);
        noRadio->setObjectName("noRadio");
        noRadio->setChecked(false);

        grid->addWidget(noRadio, 6, 0, 1, 2);

        spacer3 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        grid->addItem(spacer3, 7, 1, 1, 1);

#if QT_CONFIG(shortcut)
        pathLabel->setBuddy(pathRequester);
        nameLabel->setBuddy(nameText);
#endif // QT_CONFIG(shortcut)

        retranslateUi(DirResourceImportTypeWidget);

        QMetaObject::connectSlotsByName(DirResourceImportTypeWidget);
    } // setupUi

    void retranslateUi(QWidget *DirResourceImportTypeWidget)
    {
        mergeRadio->setText(tr2i18n("Import into existing calendar file resource", "@option:radio"));
#if QT_CONFIG(whatsthis)
        mergeResource->setWhatsThis(tr2i18n("Select the resource to import the directory resource's alarms into.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        newRadio->setText(tr2i18n("Import into new calendar file resource", "@option:radio"));
        pathLabel->setText(tr2i18n("Filename:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        pathRequester->setToolTip(tr2i18n("Select the file to contain this resource. The file must not already exist.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        pathRequester->setWhatsThis(tr2i18n("Select the file to contain this resource.\n"
"The file must not already exist.\n"
"Note that if the URL of a remote file is specified, monitoring for file changes will not work.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        nameLabel->setText(tr2i18n("Display name:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        nameText->setToolTip(tr2i18n("Enter the name used to identify this resource in displays.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        nameText->setWhatsThis(tr2i18n("Enter the name used to identify this resource in displays.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        noRadio->setText(tr2i18n("Do not import", "@option:radio"));
        (void)DirResourceImportTypeWidget;
    } // retranslateUi

};

namespace Ui {
    class DirResourceImportTypeWidget: public Ui_DirResourceImportTypeWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DIRRESOURCEIMPORTDIALOG_TYPE_H

