/****************************************************************************
** Meta object code from reading C++ file 'recurrenceedit_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/recurrenceedit_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'recurrenceedit_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6NoRuleE_t {};
} // unnamed namespace

template <> constexpr inline auto NoRule::qt_create_metaobjectdata<qt_meta_tag_ZN6NoRuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NoRule"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NoRule, qt_meta_tag_ZN6NoRuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NoRule::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6NoRuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6NoRuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6NoRuleE_t>.metaTypes,
    nullptr
} };

void NoRule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NoRule *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *NoRule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NoRule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6NoRuleE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int NoRule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN4RuleE_t {};
} // unnamed namespace

template <> constexpr inline auto Rule::qt_create_metaobjectdata<qt_meta_tag_ZN4RuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Rule",
        "frequencyChanged",
        "",
        "changed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'frequencyChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Rule, qt_meta_tag_ZN4RuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Rule::staticMetaObject = { {
    QMetaObject::SuperData::link<NoRule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4RuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4RuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4RuleE_t>.metaTypes,
    nullptr
} };

void Rule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Rule *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->frequencyChanged(); break;
        case 1: _t->changed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Rule::*)()>(_a, &Rule::frequencyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Rule::*)()>(_a, &Rule::changed, 1))
            return;
    }
}

const QMetaObject *Rule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Rule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4RuleE_t>.strings))
        return static_cast<void*>(this);
    return NoRule::qt_metacast(_clname);
}

int Rule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NoRule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void Rule::frequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Rule::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN12SubDailyRuleE_t {};
} // unnamed namespace

template <> constexpr inline auto SubDailyRule::qt_create_metaobjectdata<qt_meta_tag_ZN12SubDailyRuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SubDailyRule"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SubDailyRule, qt_meta_tag_ZN12SubDailyRuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SubDailyRule::staticMetaObject = { {
    QMetaObject::SuperData::link<Rule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SubDailyRuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SubDailyRuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12SubDailyRuleE_t>.metaTypes,
    nullptr
} };

void SubDailyRule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SubDailyRule *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *SubDailyRule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SubDailyRule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SubDailyRuleE_t>.strings))
        return static_cast<void*>(this);
    return Rule::qt_metacast(_clname);
}

int SubDailyRule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Rule::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN11DayWeekRuleE_t {};
} // unnamed namespace

template <> constexpr inline auto DayWeekRule::qt_create_metaobjectdata<qt_meta_tag_ZN11DayWeekRuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DayWeekRule"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DayWeekRule, qt_meta_tag_ZN11DayWeekRuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DayWeekRule::staticMetaObject = { {
    QMetaObject::SuperData::link<Rule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DayWeekRuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DayWeekRuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11DayWeekRuleE_t>.metaTypes,
    nullptr
} };

void DayWeekRule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DayWeekRule *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DayWeekRule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DayWeekRule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DayWeekRuleE_t>.strings))
        return static_cast<void*>(this);
    return Rule::qt_metacast(_clname);
}

int DayWeekRule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Rule::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN9DailyRuleE_t {};
} // unnamed namespace

template <> constexpr inline auto DailyRule::qt_create_metaobjectdata<qt_meta_tag_ZN9DailyRuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DailyRule"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DailyRule, qt_meta_tag_ZN9DailyRuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DailyRule::staticMetaObject = { {
    QMetaObject::SuperData::link<DayWeekRule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DailyRuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DailyRuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9DailyRuleE_t>.metaTypes,
    nullptr
} };

void DailyRule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DailyRule *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DailyRule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DailyRule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DailyRuleE_t>.strings))
        return static_cast<void*>(this);
    return DayWeekRule::qt_metacast(_clname);
}

int DailyRule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DayWeekRule::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN10WeeklyRuleE_t {};
} // unnamed namespace

template <> constexpr inline auto WeeklyRule::qt_create_metaobjectdata<qt_meta_tag_ZN10WeeklyRuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WeeklyRule"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WeeklyRule, qt_meta_tag_ZN10WeeklyRuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WeeklyRule::staticMetaObject = { {
    QMetaObject::SuperData::link<DayWeekRule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10WeeklyRuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10WeeklyRuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10WeeklyRuleE_t>.metaTypes,
    nullptr
} };

void WeeklyRule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WeeklyRule *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *WeeklyRule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WeeklyRule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10WeeklyRuleE_t>.strings))
        return static_cast<void*>(this);
    return DayWeekRule::qt_metacast(_clname);
}

int WeeklyRule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DayWeekRule::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13MonthYearRuleE_t {};
} // unnamed namespace

template <> constexpr inline auto MonthYearRule::qt_create_metaobjectdata<qt_meta_tag_ZN13MonthYearRuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MonthYearRule",
        "typeChanged",
        "",
        "DayPosType",
        "clicked",
        "QAbstractButton*",
        "slotDaySelected",
        "index"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(enum DayPosType)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'clicked'
        QtMocHelpers::SlotData<void(QAbstractButton *, QAbstractButton *)>(4, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 5, 2 }, { 0x80000000 | 5, 2 },
        }}),
        // Slot 'slotDaySelected'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MonthYearRule, qt_meta_tag_ZN13MonthYearRuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MonthYearRule::staticMetaObject = { {
    QMetaObject::SuperData::link<Rule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MonthYearRuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MonthYearRuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13MonthYearRuleE_t>.metaTypes,
    nullptr
} };

void MonthYearRule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MonthYearRule *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<enum DayPosType>>(_a[1]))); break;
        case 1: _t->clicked((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[2]))); break;
        case 2: _t->slotDaySelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractButton* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MonthYearRule::*)(DayPosType )>(_a, &MonthYearRule::typeChanged, 0))
            return;
    }
}

const QMetaObject *MonthYearRule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MonthYearRule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MonthYearRuleE_t>.strings))
        return static_cast<void*>(this);
    return Rule::qt_metacast(_clname);
}

int MonthYearRule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Rule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void MonthYearRule::typeChanged(DayPosType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN11MonthlyRuleE_t {};
} // unnamed namespace

template <> constexpr inline auto MonthlyRule::qt_create_metaobjectdata<qt_meta_tag_ZN11MonthlyRuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MonthlyRule"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MonthlyRule, qt_meta_tag_ZN11MonthlyRuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MonthlyRule::staticMetaObject = { {
    QMetaObject::SuperData::link<MonthYearRule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MonthlyRuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MonthlyRuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11MonthlyRuleE_t>.metaTypes,
    nullptr
} };

void MonthlyRule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MonthlyRule *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *MonthlyRule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MonthlyRule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MonthlyRuleE_t>.strings))
        return static_cast<void*>(this);
    return MonthYearRule::qt_metacast(_clname);
}

int MonthlyRule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MonthYearRule::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN10YearlyRuleE_t {};
} // unnamed namespace

template <> constexpr inline auto YearlyRule::qt_create_metaobjectdata<qt_meta_tag_ZN10YearlyRuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "YearlyRule",
        "clicked",
        "",
        "QAbstractButton*",
        "enableFeb29"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'clicked'
        QtMocHelpers::SlotData<void(QAbstractButton *, QAbstractButton *)>(1, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 3, 2 },
        }}),
        // Slot 'enableFeb29'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<YearlyRule, qt_meta_tag_ZN10YearlyRuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject YearlyRule::staticMetaObject = { {
    QMetaObject::SuperData::link<MonthYearRule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10YearlyRuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10YearlyRuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10YearlyRuleE_t>.metaTypes,
    nullptr
} };

void YearlyRule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<YearlyRule *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clicked((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[2]))); break;
        case 1: _t->enableFeb29(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractButton* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *YearlyRule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *YearlyRule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10YearlyRuleE_t>.strings))
        return static_cast<void*>(this);
    return MonthYearRule::qt_metacast(_clname);
}

int YearlyRule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MonthYearRule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
