/****************************************************************************
** Meta object code from reading C++ file 'editdlg.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/editdlg.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'editdlg.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12EditAlarmDlgE_t {};
} // unnamed namespace

template <> constexpr inline auto EditAlarmDlg::qt_create_metaobjectdata<qt_meta_tag_ZN12EditAlarmDlgE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EditAlarmDlg",
        "slotTry",
        "",
        "slotHelp",
        "slotDefault",
        "slotButtonClicked",
        "QAbstractButton*",
        "contentsChanged",
        "slotRecurTypeChange",
        "repeatType",
        "slotRecurFrequencyChange",
        "slotEditDeferral",
        "slotCancelSkip",
        "slotShowMainPage",
        "slotShowRecurrenceEdit",
        "slotAnyTimeToggled",
        "anyTime",
        "slotTemplateTimeType",
        "slotSetSubRepetition",
        "slotResize",
        "focusFixTimer"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotTry'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotHelp'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDefault'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotButtonClicked'
        QtMocHelpers::SlotData<void(QAbstractButton *)>(5, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'contentsChanged'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotRecurTypeChange'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'slotRecurFrequencyChange'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditDeferral'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCancelSkip'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowMainPage'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowRecurrenceEdit'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAnyTimeToggled'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'slotTemplateTimeType'
        QtMocHelpers::SlotData<void(QAbstractButton *, QAbstractButton *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotSetSubRepetition'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResize'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'focusFixTimer'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditAlarmDlg, qt_meta_tag_ZN12EditAlarmDlgE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EditAlarmDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12EditAlarmDlgE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12EditAlarmDlgE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12EditAlarmDlgE_t>.metaTypes,
    nullptr
} };

void EditAlarmDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditAlarmDlg *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotTry(); break;
        case 1: _t->slotHelp(); break;
        case 2: _t->slotDefault(); break;
        case 3: _t->slotButtonClicked((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1]))); break;
        case 4: _t->contentsChanged(); break;
        case 5: _t->slotRecurTypeChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->slotRecurFrequencyChange(); break;
        case 7: _t->slotEditDeferral(); break;
        case 8: _t->slotCancelSkip(); break;
        case 9: _t->slotShowMainPage(); break;
        case 10: _t->slotShowRecurrenceEdit(); break;
        case 11: _t->slotAnyTimeToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->slotTemplateTimeType((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[2]))); break;
        case 13: _t->slotSetSubRepetition(); break;
        case 14: _t->slotResize(); break;
        case 15: _t->focusFixTimer(); break;
        default: ;
        }
    }
}

const QMetaObject *EditAlarmDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EditAlarmDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12EditAlarmDlgE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int EditAlarmDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}
QT_WARNING_POP
