/****************************************************************************
** Meta object code from reading C++ file 'preferences.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/preferences.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'preferences.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PreferencesE_t {};
} // unnamed namespace

template <> constexpr inline auto Preferences::qt_create_metaobjectdata<qt_meta_tag_ZN11PreferencesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Preferences",
        "timeZoneChanged",
        "",
        "KAlarmCal::KADateTime::Spec",
        "newTz",
        "holidaysChanged",
        "KAlarmCal::Holidays",
        "newHolidays",
        "startOfDayChanged",
        "newStartOfDay",
        "workTimeChanged",
        "startTime",
        "endTime",
        "QBitArray",
        "workDays",
        "timeZoneChange",
        "holidaysChange",
        "regionCode",
        "startDayChange",
        "workTimeChange",
        "days"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'timeZoneChanged'
        QtMocHelpers::SignalData<void(const KAlarmCal::KADateTime::Spec &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'holidaysChanged'
        QtMocHelpers::SignalData<void(const KAlarmCal::Holidays &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'startOfDayChanged'
        QtMocHelpers::SignalData<void(const QTime &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QTime, 9 },
        }}),
        // Signal 'workTimeChanged'
        QtMocHelpers::SignalData<void(const QTime &, const QTime &, const QBitArray &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QTime, 11 }, { QMetaType::QTime, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'timeZoneChange'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'holidaysChange'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'startDayChange'
        QtMocHelpers::SlotData<void(const QDateTime &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QDateTime, 2 },
        }}),
        // Slot 'workTimeChange'
        QtMocHelpers::SlotData<void(const QDateTime &, const QDateTime &, int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QDateTime, 2 }, { QMetaType::QDateTime, 2 }, { QMetaType::Int, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Preferences, qt_meta_tag_ZN11PreferencesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Preferences::staticMetaObject = { {
    QMetaObject::SuperData::link<PreferencesBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PreferencesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PreferencesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PreferencesE_t>.metaTypes,
    nullptr
} };

void Preferences::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Preferences *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->timeZoneChanged((*reinterpret_cast<std::add_pointer_t<KAlarmCal::KADateTime::Spec>>(_a[1]))); break;
        case 1: _t->holidaysChanged((*reinterpret_cast<std::add_pointer_t<KAlarmCal::Holidays>>(_a[1]))); break;
        case 2: _t->startOfDayChanged((*reinterpret_cast<std::add_pointer_t<QTime>>(_a[1]))); break;
        case 3: _t->workTimeChanged((*reinterpret_cast<std::add_pointer_t<QTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QTime>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QBitArray>>(_a[3]))); break;
        case 4: _t->timeZoneChange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->holidaysChange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->startDayChange((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 7: _t->workTimeChange((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KAlarmCal::KADateTime::Spec >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)(const KAlarmCal::KADateTime::Spec & )>(_a, &Preferences::timeZoneChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)(const KAlarmCal::Holidays & )>(_a, &Preferences::holidaysChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)(const QTime & )>(_a, &Preferences::startOfDayChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Preferences::*)(const QTime & , const QTime & , const QBitArray & )>(_a, &Preferences::workTimeChanged, 3))
            return;
    }
}

const QMetaObject *Preferences::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Preferences::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PreferencesE_t>.strings))
        return static_cast<void*>(this);
    return PreferencesBase::qt_metacast(_clname);
}

int Preferences::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PreferencesBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Preferences::timeZoneChanged(const KAlarmCal::KADateTime::Spec & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Preferences::holidaysChanged(const KAlarmCal::Holidays & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Preferences::startOfDayChanged(const QTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Preferences::workTimeChanged(const QTime & _t1, const QTime & _t2, const QBitArray & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
