/********************************************************************************
** Form generated from reading UI file 'singlefileresourceconfigdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SINGLEFILERESOURCECONFIGDIALOG_H
#define UI_SINGLEFILERESOURCECONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "ktextedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_SingleFileResourceConfigWidget
{
public:
    QVBoxLayout *mainLayout;
    QGroupBox *pathGroupBox;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout;
    QLabel *pathLabel;
    KUrlRequester *pathRequester;
    QLineEdit *pathText;
    QHBoxLayout *verticalLayout;
    QLabel *statusLabel;
    KTextEdit *pathDescription;
    QGroupBox *alarmTypeGroupBox;
    QVBoxLayout *gridLayout;
    QHBoxLayout *layout;
    QRadioButton *activeRadio;
    QRadioButton *archivedRadio;
    QRadioButton *templateRadio;
    KTextEdit *alarmTypeDescription;
    QHBoxLayout *horizontalLayout_4;
    QLabel *alarmTypeLabel;
    QLineEdit *activeAlarmsText;
    QLineEdit *archivedAlarmsText;
    QLineEdit *templateAlarmsText;
    QGroupBox *nameGroupBox;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_1;
    KLineEdit *displayNameText;
    KTextEdit *nameDescription;
    QGroupBox *readOnlyGroupBox;
    QVBoxLayout *gridLayout_4;
    QCheckBox *readOnlyCheckbox;
    KTextEdit *readOnlyDescription;
    QDialogButtonBox *buttonBox;
    QButtonGroup *alarmTypeGroup;

    void setupUi(QWidget *SingleFileResourceConfigWidget)
    {
        if (SingleFileResourceConfigWidget->objectName().isEmpty())
            SingleFileResourceConfigWidget->setObjectName("SingleFileResourceConfigWidget");
        SingleFileResourceConfigWidget->resize(580, 0);
        mainLayout = new QVBoxLayout(SingleFileResourceConfigWidget);
        mainLayout->setObjectName("mainLayout");
        pathGroupBox = new QGroupBox(SingleFileResourceConfigWidget);
        pathGroupBox->setObjectName("pathGroupBox");
        verticalLayout_4 = new QVBoxLayout(pathGroupBox);
        verticalLayout_4->setObjectName("verticalLayout_4");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        pathLabel = new QLabel(pathGroupBox);
        pathLabel->setObjectName("pathLabel");

        horizontalLayout->addWidget(pathLabel);

        pathRequester = new KUrlRequester(pathGroupBox);
        pathRequester->setObjectName("pathRequester");

        horizontalLayout->addWidget(pathRequester);

        pathText = new QLineEdit(pathGroupBox);
        pathText->setObjectName("pathText");
        pathText->setReadOnly(true);

        horizontalLayout->addWidget(pathText);


        verticalLayout_4->addLayout(horizontalLayout);

        verticalLayout = new QHBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        statusLabel = new QLabel(pathGroupBox);
        statusLabel->setObjectName("statusLabel");
        statusLabel->setText(QString::fromUtf8("Status:"));

        verticalLayout->addWidget(statusLabel);


        verticalLayout_4->addLayout(verticalLayout);

        pathDescription = new KTextEdit(pathGroupBox);
        pathDescription->setObjectName("pathDescription");
        pathDescription->setReadOnly(true);
        pathDescription->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);

        verticalLayout_4->addWidget(pathDescription);


        mainLayout->addWidget(pathGroupBox);

        alarmTypeGroupBox = new QGroupBox(SingleFileResourceConfigWidget);
        alarmTypeGroupBox->setObjectName("alarmTypeGroupBox");
        gridLayout = new QVBoxLayout(alarmTypeGroupBox);
        gridLayout->setObjectName("gridLayout");
        layout = new QHBoxLayout();
        layout->setObjectName("layout");
        activeRadio = new QRadioButton(alarmTypeGroupBox);
        alarmTypeGroup = new QButtonGroup(SingleFileResourceConfigWidget);
        alarmTypeGroup->setObjectName("alarmTypeGroup");
        alarmTypeGroup->addButton(activeRadio);
        activeRadio->setObjectName("activeRadio");
        activeRadio->setChecked(false);

        layout->addWidget(activeRadio);

        archivedRadio = new QRadioButton(alarmTypeGroupBox);
        alarmTypeGroup->addButton(archivedRadio);
        archivedRadio->setObjectName("archivedRadio");
        archivedRadio->setChecked(false);

        layout->addWidget(archivedRadio);

        templateRadio = new QRadioButton(alarmTypeGroupBox);
        alarmTypeGroup->addButton(templateRadio);
        templateRadio->setObjectName("templateRadio");
        templateRadio->setChecked(false);

        layout->addWidget(templateRadio);


        gridLayout->addLayout(layout);

        alarmTypeDescription = new KTextEdit(alarmTypeGroupBox);
        alarmTypeDescription->setObjectName("alarmTypeDescription");
        alarmTypeDescription->setReadOnly(true);
        alarmTypeDescription->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);

        gridLayout->addWidget(alarmTypeDescription);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        alarmTypeLabel = new QLabel(alarmTypeGroupBox);
        alarmTypeLabel->setObjectName("alarmTypeLabel");

        horizontalLayout_4->addWidget(alarmTypeLabel);

        activeAlarmsText = new QLineEdit(alarmTypeGroupBox);
        activeAlarmsText->setObjectName("activeAlarmsText");
        activeAlarmsText->setReadOnly(true);
        activeAlarmsText->setVisible(false);

        horizontalLayout_4->addWidget(activeAlarmsText);

        archivedAlarmsText = new QLineEdit(alarmTypeGroupBox);
        archivedAlarmsText->setObjectName("archivedAlarmsText");
        archivedAlarmsText->setReadOnly(true);
        archivedAlarmsText->setVisible(false);

        horizontalLayout_4->addWidget(archivedAlarmsText);

        templateAlarmsText = new QLineEdit(alarmTypeGroupBox);
        templateAlarmsText->setObjectName("templateAlarmsText");
        templateAlarmsText->setReadOnly(true);
        templateAlarmsText->setVisible(false);

        horizontalLayout_4->addWidget(templateAlarmsText);


        gridLayout->addLayout(horizontalLayout_4);


        mainLayout->addWidget(alarmTypeGroupBox);

        nameGroupBox = new QGroupBox(SingleFileResourceConfigWidget);
        nameGroupBox->setObjectName("nameGroupBox");
        verticalLayout_2 = new QVBoxLayout(nameGroupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_1 = new QLabel(nameGroupBox);
        label_1->setObjectName("label_1");

        horizontalLayout_2->addWidget(label_1);

        displayNameText = new KLineEdit(nameGroupBox);
        displayNameText->setObjectName("displayNameText");

        horizontalLayout_2->addWidget(displayNameText);


        verticalLayout_2->addLayout(horizontalLayout_2);

        nameDescription = new KTextEdit(nameGroupBox);
        nameDescription->setObjectName("nameDescription");
        nameDescription->setReadOnly(true);
        nameDescription->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);

        verticalLayout_2->addWidget(nameDescription);


        mainLayout->addWidget(nameGroupBox);

        readOnlyGroupBox = new QGroupBox(SingleFileResourceConfigWidget);
        readOnlyGroupBox->setObjectName("readOnlyGroupBox");
        gridLayout_4 = new QVBoxLayout(readOnlyGroupBox);
        gridLayout_4->setObjectName("gridLayout_4");
        readOnlyCheckbox = new QCheckBox(readOnlyGroupBox);
        readOnlyCheckbox->setObjectName("readOnlyCheckbox");
        readOnlyCheckbox->setChecked(false);

        gridLayout_4->addWidget(readOnlyCheckbox);

        readOnlyDescription = new KTextEdit(readOnlyGroupBox);
        readOnlyDescription->setObjectName("readOnlyDescription");
        readOnlyDescription->setReadOnly(true);
        readOnlyDescription->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);

        gridLayout_4->addWidget(readOnlyDescription);


        mainLayout->addWidget(readOnlyGroupBox);

        buttonBox = new QDialogButtonBox(SingleFileResourceConfigWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);

        mainLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        pathLabel->setBuddy(pathRequester);
        label_1->setBuddy(displayNameText);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SingleFileResourceConfigWidget);

        QMetaObject::connectSlotsByName(SingleFileResourceConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *SingleFileResourceConfigWidget)
    {
        pathGroupBox->setTitle(tr2i18n("Calendar File", "@title:group"));
        pathLabel->setText(tr2i18n("Filename:", "@label:textbox"));
        pathDescription->setHtml(tr2i18n("Select the file to hold this calendar. If the file does not exist, it will be created. The URL of a remote file can also be specified, but note that monitoring for file changes will not work in this case.", nullptr));
        alarmTypeGroupBox->setTitle(tr2i18n("Alarm Type", "@title:group"));
        activeRadio->setText(tr2i18n("Active Alarms", "@option:radio"));
        archivedRadio->setText(tr2i18n("Archived Alarms", "@option:radio"));
        templateRadio->setText(tr2i18n("Alarm Templates", "@option:radio"));
        alarmTypeDescription->setHtml(tr2i18n("Select which alarm type this calendar should contain.", nullptr));
        alarmTypeLabel->setText(tr2i18n("Alarm type:", "@label:textbox"));
        activeAlarmsText->setText(tr2i18n("Active Alarms", "@item"));
        archivedAlarmsText->setText(tr2i18n("Archived Alarms", "@item"));
        templateAlarmsText->setText(tr2i18n("Alarm Templates", "@item"));
        nameGroupBox->setTitle(tr2i18n("Display Name", "@title:group"));
        label_1->setText(tr2i18n("Name:", "@label:textbox"));
        nameDescription->setHtml(tr2i18n("Enter the display name used to identify this calendar.", nullptr));
        readOnlyGroupBox->setTitle(tr2i18n("Access Rights", "@title:group"));
        readOnlyCheckbox->setText(tr2i18n("Read only", "@option:check"));
        readOnlyDescription->setHtml(tr2i18n("If read-only mode is enabled, no changes will be written to the file. Read-only mode will be automatically enabled if you do not have write access to the file or the file is on a remote server that does not support write access.", nullptr));
        (void)SingleFileResourceConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class SingleFileResourceConfigWidget: public Ui_SingleFileResourceConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SINGLEFILERESOURCECONFIGDIALOG_H

