/****************************************************************************
** Meta object code from reading C++ file 'messagedisplayhelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/messagedisplayhelper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'messagedisplayhelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20MessageDisplayHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto MessageDisplayHelper::qt_create_metaobjectdata<qt_meta_tag_ZN20MessageDisplayHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MessageDisplayHelper",
        "textsChanged",
        "",
        "DisplayTexts::TextIds",
        "change",
        "commandExited",
        "success",
        "autoCloseNow",
        "showRestoredAlarm",
        "editCloseOk",
        "editCloseCancel",
        "checkDeferralLimit",
        "slotSpeak",
        "audioTerminating",
        "startAudio",
        "stopAudioPlay",
        "playReady",
        "playFinished",
        "slotSetRemainingTextDay",
        "slotSetRemainingTextMinute",
        "readProcessOutput",
        "ShellProcess*",
        "commandCompleted",
        "ShellProcess::Status"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'textsChanged'
        QtMocHelpers::SignalData<void(DisplayTexts::TextIds, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'textsChanged'
        QtMocHelpers::SignalData<void(DisplayTexts::TextIds)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'commandExited'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'autoCloseNow'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showRestoredAlarm'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editCloseOk'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editCloseCancel'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkDeferralLimit'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSpeak'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'audioTerminating'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'startAudio'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopAudioPlay'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playReady'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playFinished'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetRemainingTextDay'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetRemainingTextMinute'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'readProcessOutput'
        QtMocHelpers::SlotData<void(ShellProcess *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 2 },
        }}),
        // Slot 'commandCompleted'
        QtMocHelpers::SlotData<void(ShellProcess::Status)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MessageDisplayHelper, qt_meta_tag_ZN20MessageDisplayHelperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MessageDisplayHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20MessageDisplayHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20MessageDisplayHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20MessageDisplayHelperE_t>.metaTypes,
    nullptr
} };

void MessageDisplayHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MessageDisplayHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->textsChanged((*reinterpret_cast<std::add_pointer_t<DisplayTexts::TextIds>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->textsChanged((*reinterpret_cast<std::add_pointer_t<DisplayTexts::TextIds>>(_a[1]))); break;
        case 2: _t->commandExited((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->autoCloseNow(); break;
        case 4: _t->showRestoredAlarm(); break;
        case 5: _t->editCloseOk(); break;
        case 6: _t->editCloseCancel(); break;
        case 7: _t->checkDeferralLimit(); break;
        case 8: _t->slotSpeak(); break;
        case 9: _t->audioTerminating(); break;
        case 10: _t->startAudio(); break;
        case 11: _t->stopAudioPlay(); break;
        case 12: _t->playReady(); break;
        case 13: _t->playFinished(); break;
        case 14: _t->slotSetRemainingTextDay(); break;
        case 15: _t->slotSetRemainingTextMinute(); break;
        case 16: _t->readProcessOutput((*reinterpret_cast<std::add_pointer_t<ShellProcess*>>(_a[1]))); break;
        case 17: _t->commandCompleted((*reinterpret_cast<std::add_pointer_t<ShellProcess::Status>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ShellProcess* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MessageDisplayHelper::*)(DisplayTexts::TextIds , const QString & )>(_a, &MessageDisplayHelper::textsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MessageDisplayHelper::*)(bool )>(_a, &MessageDisplayHelper::commandExited, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MessageDisplayHelper::*)()>(_a, &MessageDisplayHelper::autoCloseNow, 3))
            return;
    }
}

const QMetaObject *MessageDisplayHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MessageDisplayHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20MessageDisplayHelperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MessageDisplayHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void MessageDisplayHelper::textsChanged(DisplayTexts::TextIds _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 2
void MessageDisplayHelper::commandExited(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void MessageDisplayHelper::autoCloseNow()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
