/****************************************************************************
** Meta object code from reading C++ file 'eventmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/resources/eventmodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'eventmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14EventListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto EventListModel::qt_create_metaobjectdata<qt_meta_tag_ZN14EventListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EventListModel",
        "haveEventsStatus",
        "",
        "have",
        "slotResourcePopulated",
        "Resource&",
        "slotRowsInserted",
        "slotRowsRemoved",
        "resourceSettingsChanged",
        "ResourceType::Changes"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'haveEventsStatus'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'slotResourcePopulated'
        QtMocHelpers::SlotData<void(Resource &)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'slotRowsInserted'
        QtMocHelpers::SlotData<void(Resource &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'slotRowsRemoved'
        QtMocHelpers::SlotData<void(Resource &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'resourceSettingsChanged'
        QtMocHelpers::SlotData<void(Resource &, ResourceType::Changes)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 2 }, { 0x80000000 | 9, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EventListModel, qt_meta_tag_ZN14EventListModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EventListModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14EventListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14EventListModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14EventListModelE_t>.metaTypes,
    nullptr
} };

void EventListModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EventListModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->haveEventsStatus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->slotResourcePopulated((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1]))); break;
        case 2: _t->slotRowsInserted((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1]))); break;
        case 3: _t->slotRowsRemoved((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1]))); break;
        case 4: _t->resourceSettingsChanged((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ResourceType::Changes>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EventListModel::*)(bool )>(_a, &EventListModel::haveEventsStatus, 0))
            return;
    }
}

const QMetaObject *EventListModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventListModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14EventListModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int EventListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void EventListModel::haveEventsStatus(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN14AlarmListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AlarmListModel::qt_create_metaobjectdata<qt_meta_tag_ZN14AlarmListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AlarmListModel",
        "slotResourceSettingsChanged",
        "",
        "Resource&",
        "ResourceType::Changes",
        "slotResourceRemoved",
        "KAlarmCal::ResourceId",
        "slotEventUpdated",
        "KAlarmCal::KAEvent",
        "slotEventsRemoved",
        "QList<KAlarmCal::KAEvent>"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotResourceSettingsChanged'
        QtMocHelpers::SlotData<void(Resource &, ResourceType::Changes)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Slot 'slotResourceRemoved'
        QtMocHelpers::SlotData<void(KAlarmCal::ResourceId)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotEventUpdated'
        QtMocHelpers::SlotData<void(Resource &, const KAlarmCal::KAEvent &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 8, 2 },
        }}),
        // Slot 'slotEventsRemoved'
        QtMocHelpers::SlotData<void(Resource &, const QList<KAlarmCal::KAEvent> &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 10, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AlarmListModel, qt_meta_tag_ZN14AlarmListModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AlarmListModel::staticMetaObject = { {
    QMetaObject::SuperData::link<EventListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AlarmListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AlarmListModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14AlarmListModelE_t>.metaTypes,
    nullptr
} };

void AlarmListModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AlarmListModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotResourceSettingsChanged((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ResourceType::Changes>>(_a[2]))); break;
        case 1: _t->slotResourceRemoved((*reinterpret_cast<std::add_pointer_t<KAlarmCal::ResourceId>>(_a[1]))); break;
        case 2: _t->slotEventUpdated((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KAlarmCal::KAEvent>>(_a[2]))); break;
        case 3: _t->slotEventsRemoved((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<KAlarmCal::KAEvent>>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KAlarmCal::KAEvent >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<KAlarmCal::KAEvent> >(); break;
            }
            break;
        }
    }
}

const QMetaObject *AlarmListModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AlarmListModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AlarmListModelE_t>.strings))
        return static_cast<void*>(this);
    return EventListModel::qt_metacast(_clname);
}

int AlarmListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EventListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN17TemplateListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TemplateListModel::qt_create_metaobjectdata<qt_meta_tag_ZN17TemplateListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TemplateListModel"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TemplateListModel, qt_meta_tag_ZN17TemplateListModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TemplateListModel::staticMetaObject = { {
    QMetaObject::SuperData::link<EventListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TemplateListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TemplateListModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17TemplateListModelE_t>.metaTypes,
    nullptr
} };

void TemplateListModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TemplateListModel *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *TemplateListModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TemplateListModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TemplateListModelE_t>.strings))
        return static_cast<void*>(this);
    return EventListModel::qt_metacast(_clname);
}

int TemplateListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EventListModel::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
