/********************************************************************************
** Form generated from reading UI file 'dirresourceimportdialog_intro.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIRRESOURCEIMPORTDIALOG_INTRO_H
#define UI_DIRRESOURCEIMPORTDIALOG_INTRO_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DirResourceImportIntroWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *warning1;
    QLabel *warning2;
    QLabel *label1;
    QLineEdit *dirNameLabel;
    QLabel *label2;
    QLineEdit *dirPathLabel;
    QLabel *label3;
    QLineEdit *dirTypesLabel;
    QLabel *note;

    void setupUi(QWidget *DirResourceImportIntroWidget)
    {
        if (DirResourceImportIntroWidget->objectName().isEmpty())
            DirResourceImportIntroWidget->setObjectName("DirResourceImportIntroWidget");
        gridLayout = new QGridLayout(DirResourceImportIntroWidget);
        gridLayout->setObjectName("gridLayout");
        warning1 = new QLabel(DirResourceImportIntroWidget);
        warning1->setObjectName("warning1");
        warning1->setWordWrap(true);

        gridLayout->addWidget(warning1, 0, 0, 1, 2);

        warning2 = new QLabel(DirResourceImportIntroWidget);
        warning2->setObjectName("warning2");
        warning2->setWordWrap(true);

        gridLayout->addWidget(warning2, 1, 0, 1, 2);

        label1 = new QLabel(DirResourceImportIntroWidget);
        label1->setObjectName("label1");

        gridLayout->addWidget(label1, 2, 0, 1, 1);

        dirNameLabel = new QLineEdit(DirResourceImportIntroWidget);
        dirNameLabel->setObjectName("dirNameLabel");
        dirNameLabel->setReadOnly(true);

        gridLayout->addWidget(dirNameLabel, 2, 1, 1, 1);

        label2 = new QLabel(DirResourceImportIntroWidget);
        label2->setObjectName("label2");

        gridLayout->addWidget(label2, 3, 0, 1, 1);

        dirPathLabel = new QLineEdit(DirResourceImportIntroWidget);
        dirPathLabel->setObjectName("dirPathLabel");
        dirPathLabel->setReadOnly(true);

        gridLayout->addWidget(dirPathLabel, 3, 1, 1, 1);

        label3 = new QLabel(DirResourceImportIntroWidget);
        label3->setObjectName("label3");

        gridLayout->addWidget(label3, 4, 0, 1, 1);

        dirTypesLabel = new QLineEdit(DirResourceImportIntroWidget);
        dirTypesLabel->setObjectName("dirTypesLabel");
        dirTypesLabel->setReadOnly(true);

        gridLayout->addWidget(dirTypesLabel, 4, 1, 1, 1);

        note = new QLabel(DirResourceImportIntroWidget);
        note->setObjectName("note");
        note->setWordWrap(true);

        gridLayout->addWidget(note, 5, 0, 1, 2);


        retranslateUi(DirResourceImportIntroWidget);

        QMetaObject::connectSlotsByName(DirResourceImportIntroWidget);
    } // setupUi

    void retranslateUi(QWidget *DirResourceImportIntroWidget)
    {
        warning1->setText(tr2i18n("KAlarm no longer supports calendar directory resources. In order to continue using the contents of the directory resource below, you must import it into a KAlarm calendar file resource.", "@info"));
        warning2->setText(tr2i18n("KAlarm no longer supports calendar directory resources. In order to continue using the contents of the directory resource below, you must import each of its alarm types into separate KAlarm calendar file resources.", "@info"));
        label1->setText(tr2i18n("Display name:", "@label:textbox"));
        label2->setText(tr2i18n("Calendar directory:", "@label:textbox"));
        label3->setText(tr2i18n("Alarm types:", "@label:textbox"));
        note->setText(tr2i18n("If you prefer, you can import this calendar directory resource later, by using the Import Alarms menu option to import the calendar files contained within it.", "@info"));
        (void)DirResourceImportIntroWidget;
    } // retranslateUi

};

namespace Ui {
    class DirResourceImportIntroWidget: public Ui_DirResourceImportIntroWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DIRRESOURCEIMPORTDIALOG_INTRO_H

