/****************************************************************************
** Meta object code from reading C++ file 'traywindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/traywindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'traywindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10TrayWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto TrayWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10TrayWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TrayWindow",
        "deleted",
        "",
        "slotActivateRequested",
        "slotSecondaryActivateRequested",
        "slotNewAlarm",
        "EditAlarmDlg::Type",
        "slotNewFromTemplate",
        "KAEvent",
        "slotPreferences",
        "setEnabledStatus",
        "status",
        "slotHaveDisabledAlarms",
        "disabled",
        "slotQuit",
        "slotQuitAfter",
        "updateStatus",
        "updateToolTip"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'deleted'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotActivateRequested'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSecondaryActivateRequested'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewAlarm'
        QtMocHelpers::SlotData<void(EditAlarmDlg::Type)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotNewFromTemplate'
        QtMocHelpers::SlotData<void(const KAEvent &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'slotPreferences'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setEnabledStatus'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'slotHaveDisabledAlarms'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'slotQuit'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotQuitAfter'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateStatus'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateToolTip'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TrayWindow, qt_meta_tag_ZN10TrayWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TrayWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KStatusNotifierItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10TrayWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10TrayWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10TrayWindowE_t>.metaTypes,
    nullptr
} };

void TrayWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TrayWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->deleted(); break;
        case 1: _t->slotActivateRequested(); break;
        case 2: _t->slotSecondaryActivateRequested(); break;
        case 3: _t->slotNewAlarm((*reinterpret_cast<std::add_pointer_t<EditAlarmDlg::Type>>(_a[1]))); break;
        case 4: _t->slotNewFromTemplate((*reinterpret_cast<std::add_pointer_t<KAEvent>>(_a[1]))); break;
        case 5: _t->slotPreferences(); break;
        case 6: _t->setEnabledStatus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->slotHaveDisabledAlarms((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->slotQuit(); break;
        case 9: _t->slotQuitAfter(); break;
        case 10: _t->updateStatus(); break;
        case 11: _t->updateToolTip(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TrayWindow::*)()>(_a, &TrayWindow::deleted, 0))
            return;
    }
}

const QMetaObject *TrayWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TrayWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10TrayWindowE_t>.strings))
        return static_cast<void*>(this);
    return KStatusNotifierItem::qt_metacast(_clname);
}

int TrayWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KStatusNotifierItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void TrayWindow::deleted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
