/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kalarm.kalarm.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kalarmadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KalarmAdaptor
 */

KalarmAdaptor::KalarmAdaptor(DBusHandler *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KalarmAdaptor::~KalarmAdaptor()
{
    // destructor
}

bool KalarmAdaptor::cancelEvent(const QString &eventId)
{
    // handle method call org.kde.kalarm.kalarm.cancelEvent
    return parent()->cancelEvent(eventId);
}

bool KalarmAdaptor::edit(const QString &eventID)
{
    // handle method call org.kde.kalarm.kalarm.edit
    return parent()->edit(eventID);
}

bool KalarmAdaptor::editNew(const QString &templateName)
{
    // handle method call org.kde.kalarm.kalarm.editNew
    return parent()->editNew(templateName);
}

bool KalarmAdaptor::editNew(int type)
{
    // handle method call org.kde.kalarm.kalarm.editNew
    return parent()->editNew(type);
}

QString KalarmAdaptor::list()
{
    // handle method call org.kde.kalarm.kalarm.list
    return parent()->list();
}

bool KalarmAdaptor::scheduleAudio(const QString &audioFile, int volumePercent, const QString &startDateTime, int lateCancel, uint flags, int recurType, int recurInterval, const QString &endDateTime)
{
    // handle method call org.kde.kalarm.kalarm.scheduleAudio
    return parent()->scheduleAudio(audioFile, volumePercent, startDateTime, lateCancel, flags, recurType, recurInterval, endDateTime);
}

bool KalarmAdaptor::scheduleAudio(const QString &audioFile, int volumePercent, const QString &startDateTime, int lateCancel, uint flags, int recurType, int recurInterval, int recurCount)
{
    // handle method call org.kde.kalarm.kalarm.scheduleAudio
    return parent()->scheduleAudio(audioFile, volumePercent, startDateTime, lateCancel, flags, recurType, recurInterval, recurCount);
}

bool KalarmAdaptor::scheduleAudio(const QString &audioFile, int volumePercent, const QString &startDateTime, int lateCancel, uint flags, const QString &recurrence, int subRepeatInterval, int subRepeatCount)
{
    // handle method call org.kde.kalarm.kalarm.scheduleAudio
    return parent()->scheduleAudio(audioFile, volumePercent, startDateTime, lateCancel, flags, recurrence, subRepeatInterval, subRepeatCount);
}

bool KalarmAdaptor::scheduleCommand(const QString &commandLine, const QString &startDateTime, int lateCancel, uint flags, int recurType, int recurInterval, const QString &endDateTime)
{
    // handle method call org.kde.kalarm.kalarm.scheduleCommand
    return parent()->scheduleCommand(commandLine, startDateTime, lateCancel, flags, recurType, recurInterval, endDateTime);
}

bool KalarmAdaptor::scheduleCommand(const QString &commandLine, const QString &startDateTime, int lateCancel, uint flags, int recurType, int recurInterval, int recurCount)
{
    // handle method call org.kde.kalarm.kalarm.scheduleCommand
    return parent()->scheduleCommand(commandLine, startDateTime, lateCancel, flags, recurType, recurInterval, recurCount);
}

bool KalarmAdaptor::scheduleCommand(const QString &commandLine, const QString &startDateTime, int lateCancel, uint flags, const QString &recurrence, int subRepeatInterval, int subRepeatCount)
{
    // handle method call org.kde.kalarm.kalarm.scheduleCommand
    return parent()->scheduleCommand(commandLine, startDateTime, lateCancel, flags, recurrence, subRepeatInterval, subRepeatCount);
}

bool KalarmAdaptor::scheduleEmail(const QString &fromID, const QString &addresses, const QString &subject, const QString &message, const QString &attachments, const QString &startDateTime, int lateCancel, uint flags, int recurType, int recurInterval, const QString &endDateTime)
{
    // handle method call org.kde.kalarm.kalarm.scheduleEmail
    return parent()->scheduleEmail(fromID, addresses, subject, message, attachments, startDateTime, lateCancel, flags, recurType, recurInterval, endDateTime);
}

bool KalarmAdaptor::scheduleEmail(const QString &fromID, const QString &addresses, const QString &subject, const QString &message, const QString &attachments, const QString &startDateTime, int lateCancel, uint flags, int recurType, int recurInterval, int recurCount)
{
    // handle method call org.kde.kalarm.kalarm.scheduleEmail
    return parent()->scheduleEmail(fromID, addresses, subject, message, attachments, startDateTime, lateCancel, flags, recurType, recurInterval, recurCount);
}

bool KalarmAdaptor::scheduleEmail(const QString &fromID, const QString &addresses, const QString &subject, const QString &message, const QString &attachments, const QString &startDateTime, int lateCancel, uint flags, const QString &recurrence, int subRepeatInterval, int subRepeatCount)
{
    // handle method call org.kde.kalarm.kalarm.scheduleEmail
    return parent()->scheduleEmail(fromID, addresses, subject, message, attachments, startDateTime, lateCancel, flags, recurrence, subRepeatInterval, subRepeatCount);
}

bool KalarmAdaptor::scheduleFile(const QString &file, const QString &startDateTime, int lateCancel, uint flags, const QString &bgColor, const QString &audioFile, int reminderMins, int recurType, int recurInterval, const QString &endDateTime)
{
    // handle method call org.kde.kalarm.kalarm.scheduleFile
    return parent()->scheduleFile(file, startDateTime, lateCancel, flags, bgColor, audioFile, reminderMins, recurType, recurInterval, endDateTime);
}

bool KalarmAdaptor::scheduleFile(const QString &file, const QString &startDateTime, int lateCancel, uint flags, const QString &bgColor, const QString &audioFile, int reminderMins, int recurType, int recurInterval, int recurCount)
{
    // handle method call org.kde.kalarm.kalarm.scheduleFile
    return parent()->scheduleFile(file, startDateTime, lateCancel, flags, bgColor, audioFile, reminderMins, recurType, recurInterval, recurCount);
}

bool KalarmAdaptor::scheduleFile(const QString &file, const QString &startDateTime, int lateCancel, uint flags, const QString &bgColor, const QString &audioFile, int reminderMins, const QString &recurrence, int subRepeatInterval, int subRepeatCount)
{
    // handle method call org.kde.kalarm.kalarm.scheduleFile
    return parent()->scheduleFile(file, startDateTime, lateCancel, flags, bgColor, audioFile, reminderMins, recurrence, subRepeatInterval, subRepeatCount);
}

bool KalarmAdaptor::scheduleMessage(const QString &message, const QString &startDateTime, int lateCancel, uint flags, const QString &bgColor, const QString &fgColor, const QString &font, const QString &audioFile, int reminderMins, int recurType, int recurInterval, const QString &endDateTime)
{
    // handle method call org.kde.kalarm.kalarm.scheduleMessage
    return parent()->scheduleMessage(message, startDateTime, lateCancel, flags, bgColor, fgColor, font, audioFile, reminderMins, recurType, recurInterval, endDateTime);
}

bool KalarmAdaptor::scheduleMessage(const QString &message, const QString &startDateTime, int lateCancel, uint flags, const QString &bgColor, const QString &fgColor, const QString &font, const QString &audioFile, int reminderMins, int recurType, int recurInterval, int recurCount)
{
    // handle method call org.kde.kalarm.kalarm.scheduleMessage
    return parent()->scheduleMessage(message, startDateTime, lateCancel, flags, bgColor, fgColor, font, audioFile, reminderMins, recurType, recurInterval, recurCount);
}

bool KalarmAdaptor::scheduleMessage(const QString &message, const QString &startDateTime, int lateCancel, uint flags, const QString &bgColor, const QString &fgColor, const QString &font, const QString &audioFile, int reminderMins, const QString &recurrence, int subRepeatInterval, int subRepeatCount)
{
    // handle method call org.kde.kalarm.kalarm.scheduleMessage
    return parent()->scheduleMessage(message, startDateTime, lateCancel, flags, bgColor, fgColor, font, audioFile, reminderMins, recurrence, subRepeatInterval, subRepeatCount);
}

bool KalarmAdaptor::triggerEvent(const QString &eventId)
{
    // handle method call org.kde.kalarm.kalarm.triggerEvent
    return parent()->triggerEvent(eventId);
}


#include "moc_kalarmadaptor.cpp"
