/****************************************************************************
** Meta object code from reading C++ file 'kalarmadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "kalarmadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kalarmadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KalarmAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KalarmAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN13KalarmAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KalarmAdaptor",
        "D-Bus Interface",
        "org.kde.kalarm.kalarm",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.kalarm.kalarm\">\n    <method name=\"c"
        "ancelEvent\">\n      <arg direction=\"out\" type=\"b\"/>\n      <a"
        "rg direction=\"in\" type=\"s\" name=\"eventId\"/>\n    </method>\n"
        "    <method name=\"triggerEvent\">\n      <arg direction=\"out\" t"
        "ype=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\"eventId"
        "\"/>\n    </method>\n    <method name=\"list\">\n      <arg direct"
        "ion=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"schedu"
        "leMessage\">\n      <arg direction=\"out\" type=\"b\"/>\n      <ar"
        "g direction=\"in\" type=\"s\" name=\"message\"/>\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"startDateTime\"/>\n      <arg direct"
        "ion=\"in\" type=\"i\" name=\"lateCancel\"/>\n      <arg direction="
        "\"in\" type=\"u\" name=\"flags\"/>\n      <arg direction=\"in\" ty"
        "pe=\"s\" name=\"bgColor\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"fgColor\"/>\n      <arg direction=\"in\" type=\"s\" name=\""
        "font\"/>\n      <arg direction=\"in\" type=\"s\" name=\"audioFile\""
        "/>\n      <arg direction=\"in\" type=\"i\" name=\"reminderMins\"/>"
        "\n      <arg direction=\"in\" type=\"s\" name=\"recurrence\"/>\n  "
        "    <arg direction=\"in\" type=\"i\" name=\"subRepeatInterval\"/>\n"
        "      <arg direction=\"in\" type=\"i\" name=\"subRepeatCount\"/>\n"
        "    </method>\n    <method name=\"scheduleMessage\">\n      <arg d"
        "irection=\"out\" type=\"b\"/>\n      <arg direction=\"in\" type=\""
        "s\" name=\"message\"/>\n      <arg direction=\"in\" type=\"s\" nam"
        "e=\"startDateTime\"/>\n      <arg direction=\"in\" type=\"i\" name"
        "=\"lateCancel\"/>\n      <arg direction=\"in\" type=\"u\" name=\"f"
        "lags\"/>\n      <arg direction=\"in\" type=\"s\" name=\"bgColor\"/"
        ">\n      <arg direction=\"in\" type=\"s\" name=\"fgColor\"/>\n    "
        "  <arg direction=\"in\" type=\"s\" name=\"font\"/>\n      <arg dir"
        "ection=\"in\" type=\"s\" name=\"audioFile\"/>\n      <arg directio"
        "n=\"in\" type=\"i\" name=\"reminderMins\"/>\n      <arg direction="
        "\"in\" type=\"i\" name=\"recurType\"/>\n      <arg direction=\"in\""
        " type=\"i\" name=\"recurInterval\"/>\n      <arg direction=\"in\" "
        "type=\"i\" name=\"recurCount\"/>\n    </method>\n    <method name="
        "\"scheduleMessage\">\n      <arg direction=\"out\" type=\"b\"/>\n "
        "     <arg direction=\"in\" type=\"s\" name=\"message\"/>\n      <a"
        "rg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n      <ar"
        "g direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n      <arg di"
        "rection=\"in\" type=\"u\" name=\"flags\"/>\n      <arg direction=\""
        "in\" type=\"s\" name=\"bgColor\"/>\n      <arg direction=\"in\" ty"
        "pe=\"s\" name=\"fgColor\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"font\"/>\n      <arg direction=\"in\" type=\"s\" name=\"au"
        "dioFile\"/>\n      <arg direction=\"in\" type=\"i\" name=\"reminde"
        "rMins\"/>\n      <arg direction=\"in\" type=\"i\" name=\"recurType"
        "\"/>\n      <arg direction=\"in\" type=\"i\" name=\"recurInterval\""
        "/>\n      <arg direction=\"in\" type=\"s\" name=\"endDateTime\"/>\n"
        "    </method>\n    <method name=\"scheduleFile\">\n      <arg dire"
        "ction=\"out\" type=\"b\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"file\"/>\n      <arg direction=\"in\" type=\"s\" name=\"st"
        "artDateTime\"/>\n      <arg direction=\"in\" type=\"i\" name=\"lat"
        "eCancel\"/>\n      <arg direction=\"in\" type=\"u\" name=\"flags\""
        "/>\n      <arg direction=\"in\" type=\"s\" name=\"bgColor\"/>\n   "
        "   <arg direction=\"in\" type=\"s\" name=\"audioFile\"/>\n      <a"
        "rg direction=\"in\" type=\"i\" name=\"reminderMins\"/>\n      <arg"
        " direction=\"in\" type=\"s\" name=\"recurrence\"/>\n      <arg dir"
        "ection=\"in\" type=\"i\" name=\"subRepeatInterval\"/>\n      <arg "
        "direction=\"in\" type=\"i\" name=\"subRepeatCount\"/>\n    </metho"
        "d>\n    <method name=\"scheduleFile\">\n      <arg direction=\"out"
        "\" type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\"fil"
        "e\"/>\n      <arg direction=\"in\" type=\"s\" name=\"startDateTime"
        "\"/>\n      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>"
        "\n      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n      <"
        "arg direction=\"in\" type=\"s\" name=\"bgColor\"/>\n      <arg dir"
        "ection=\"in\" type=\"s\" name=\"audioFile\"/>\n      <arg directio"
        "n=\"in\" type=\"i\" name=\"reminderMins\"/>\n      <arg direction="
        "\"in\" type=\"i\" name=\"recurType\"/>\n      <arg direction=\"in\""
        " type=\"i\" name=\"recurInterval\"/>\n      <arg direction=\"in\" "
        "type=\"i\" name=\"recurCount\"/>\n    </method>\n    <method name="
        "\"scheduleFile\">\n      <arg direction=\"out\" type=\"b\"/>\n    "
        "  <arg direction=\"in\" type=\"s\" name=\"file\"/>\n      <arg dir"
        "ection=\"in\" type=\"s\" name=\"startDateTime\"/>\n      <arg dire"
        "ction=\"in\" type=\"i\" name=\"lateCancel\"/>\n      <arg directio"
        "n=\"in\" type=\"u\" name=\"flags\"/>\n      <arg direction=\"in\" "
        "type=\"s\" name=\"bgColor\"/>\n      <arg direction=\"in\" type=\""
        "s\" name=\"audioFile\"/>\n      <arg direction=\"in\" type=\"i\" n"
        "ame=\"reminderMins\"/>\n      <arg direction=\"in\" type=\"i\" nam"
        "e=\"recurType\"/>\n      <arg direction=\"in\" type=\"i\" name=\"r"
        "ecurInterval\"/>\n      <arg direction=\"in\" type=\"s\" name=\"en"
        "dDateTime\"/>\n    </method>\n    <method name=\"scheduleCommand\""
        ">\n      <arg direction=\"out\" type=\"b\"/>\n      <arg direction"
        "=\"in\" type=\"s\" name=\"commandLine\"/>\n      <arg direction=\""
        "in\" type=\"s\" name=\"startDateTime\"/>\n      <arg direction=\"i"
        "n\" type=\"i\" name=\"lateCancel\"/>\n      <arg direction=\"in\" "
        "type=\"u\" name=\"flags\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"recurrence\"/>\n      <arg direction=\"in\" type=\"i\" nam"
        "e=\"subRepeatInterval\"/>\n      <arg direction=\"in\" type=\"i\" "
        "name=\"subRepeatCount\"/>\n    </method>\n    <method name=\"sched"
        "uleCommand\">\n      <arg direction=\"out\" type=\"b\"/>\n      <a"
        "rg direction=\"in\" type=\"s\" name=\"commandLine\"/>\n      <arg "
        "direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n      <arg d"
        "irection=\"in\" type=\"i\" name=\"lateCancel\"/>\n      <arg direc"
        "tion=\"in\" type=\"u\" name=\"flags\"/>\n      <arg direction=\"in"
        "\" type=\"i\" name=\"recurType\"/>\n      <arg direction=\"in\" ty"
        "pe=\"i\" name=\"recurInterval\"/>\n      <arg direction=\"in\" typ"
        "e=\"i\" name=\"recurCount\"/>\n    </method>\n    <method name=\"s"
        "cheduleCommand\">\n      <arg direction=\"out\" type=\"b\"/>\n    "
        "  <arg direction=\"in\" type=\"s\" name=\"commandLine\"/>\n      <"
        "arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n      <a"
        "rg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n      <arg d"
        "irection=\"in\" type=\"u\" name=\"flags\"/>\n      <arg direction="
        "\"in\" type=\"i\" name=\"recurType\"/>\n      <arg direction=\"in\""
        " type=\"i\" name=\"recurInterval\"/>\n      <arg direction=\"in\" "
        "type=\"s\" name=\"endDateTime\"/>\n    </method>\n    <method name"
        "=\"scheduleEmail\">\n      <arg direction=\"out\" type=\"b\"/>\n  "
        "    <arg direction=\"in\" type=\"s\" name=\"fromID\"/>\n      <arg"
        " direction=\"in\" type=\"s\" name=\"addresses\"/>\n      <arg dire"
        "ction=\"in\" type=\"s\" name=\"subject\"/>\n      <arg direction=\""
        "in\" type=\"s\" name=\"message\"/>\n      <arg direction=\"in\" ty"
        "pe=\"s\" name=\"attachments\"/>\n      <arg direction=\"in\" type="
        "\"s\" name=\"startDateTime\"/>\n      <arg direction=\"in\" type=\""
        "i\" name=\"lateCancel\"/>\n      <arg direction=\"in\" type=\"u\" "
        "name=\"flags\"/>\n      <arg direction=\"in\" type=\"s\" name=\"re"
        "currence\"/>\n      <arg direction=\"in\" type=\"i\" name=\"subRep"
        "eatInterval\"/>\n      <arg direction=\"in\" type=\"i\" name=\"sub"
        "RepeatCount\"/>\n    </method>\n    <method name=\"scheduleEmail\""
        ">\n      <arg direction=\"out\" type=\"b\"/>\n      <arg direction"
        "=\"in\" type=\"s\" name=\"fromID\"/>\n      <arg direction=\"in\" "
        "type=\"s\" name=\"addresses\"/>\n      <arg direction=\"in\" type="
        "\"s\" name=\"subject\"/>\n      <arg direction=\"in\" type=\"s\" n"
        "ame=\"message\"/>\n      <arg direction=\"in\" type=\"s\" name=\"a"
        "ttachments\"/>\n      <arg direction=\"in\" type=\"s\" name=\"star"
        "tDateTime\"/>\n      <arg direction=\"in\" type=\"i\" name=\"lateC"
        "ancel\"/>\n      <arg direction=\"in\" type=\"u\" name=\"flags\"/>"
        "\n      <arg direction=\"in\" type=\"i\" name=\"recurType\"/>\n   "
        "   <arg direction=\"in\" type=\"i\" name=\"recurInterval\"/>\n    "
        "  <arg direction=\"in\" type=\"i\" name=\"recurCount\"/>\n    </me"
        "thod>\n    <method name=\"scheduleEmail\">\n      <arg direction=\""
        "out\" type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\""
        "fromID\"/>\n      <arg direction=\"in\" type=\"s\" name=\"addresse"
        "s\"/>\n      <arg direction=\"in\" type=\"s\" name=\"subject\"/>\n"
        "      <arg direction=\"in\" type=\"s\" name=\"message\"/>\n      <"
        "arg direction=\"in\" type=\"s\" name=\"attachments\"/>\n      <arg"
        " direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n      <arg "
        "direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n      <arg dire"
        "ction=\"in\" type=\"u\" name=\"flags\"/>\n      <arg direction=\"i"
        "n\" type=\"i\" name=\"recurType\"/>\n      <arg direction=\"in\" t"
        "ype=\"i\" name=\"recurInterval\"/>\n      <arg direction=\"in\" ty"
        "pe=\"s\" name=\"endDateTime\"/>\n    </method>\n    <method name=\""
        "scheduleAudio\">\n      <arg direction=\"out\" type=\"b\"/>\n     "
        " <arg direction=\"in\" type=\"s\" name=\"audioFile\"/>\n      <arg"
        " direction=\"in\" type=\"i\" name=\"volumePercent\"/>\n      <arg "
        "direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n      <arg d"
        "irection=\"in\" type=\"i\" name=\"lateCancel\"/>\n      <arg direc"
        "tion=\"in\" type=\"u\" name=\"flags\"/>\n      <arg direction=\"in"
        "\" type=\"s\" name=\"recurrence\"/>\n      <arg direction=\"in\" t"
        "ype=\"i\" name=\"subRepeatInterval\"/>\n      <arg direction=\"in\""
        " type=\"i\" name=\"subRepeatCount\"/>\n    </method>\n    <method "
        "name=\"scheduleAudio\">\n      <arg direction=\"out\" type=\"b\"/>"
        "\n      <arg direction=\"in\" type=\"s\" name=\"audioFile\"/>\n   "
        "   <arg direction=\"in\" type=\"i\" name=\"volumePercent\"/>\n    "
        "  <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n     "
        " <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n      <ar"
        "g direction=\"in\" type=\"u\" name=\"flags\"/>\n      <arg directi"
        "on=\"in\" type=\"i\" name=\"recurType\"/>\n      <arg direction=\""
        "in\" type=\"i\" name=\"recurInterval\"/>\n      <arg direction=\"i"
        "n\" type=\"i\" name=\"recurCount\"/>\n    </method>\n    <method n"
        "ame=\"scheduleAudio\">\n      <arg direction=\"out\" type=\"b\"/>\n"
        "      <arg direction=\"in\" type=\"s\" name=\"audioFile\"/>\n     "
        " <arg direction=\"in\" type=\"i\" name=\"volumePercent\"/>\n      "
        "<arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n      <"
        "arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n      <arg "
        "direction=\"in\" type=\"u\" name=\"flags\"/>\n      <arg direction"
        "=\"in\" type=\"i\" name=\"recurType\"/>\n      <arg direction=\"in"
        "\" type=\"i\" name=\"recurInterval\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"endDateTime\"/>\n    </method>\n    <method nam"
        "e=\"edit\">\n      <arg direction=\"out\" type=\"b\"/>\n      <arg"
        " direction=\"in\" type=\"s\" name=\"eventID\"/>\n    </method>\n  "
        "  <method name=\"editNew\">\n      <arg direction=\"out\" type=\"b"
        "\"/>\n      <arg direction=\"in\" type=\"i\" name=\"type\"/>\n    "
        "</method>\n    <method name=\"editNew\">\n      <arg direction=\"o"
        "ut\" type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\"t"
        "emplateName\"/>\n    </method>\n  </interface>\n",
        "cancelEvent",
        "",
        "eventId",
        "edit",
        "eventID",
        "editNew",
        "templateName",
        "type",
        "list",
        "scheduleAudio",
        "audioFile",
        "volumePercent",
        "startDateTime",
        "lateCancel",
        "flags",
        "recurType",
        "recurInterval",
        "endDateTime",
        "recurCount",
        "recurrence",
        "subRepeatInterval",
        "subRepeatCount",
        "scheduleCommand",
        "commandLine",
        "scheduleEmail",
        "fromID",
        "addresses",
        "subject",
        "message",
        "attachments",
        "scheduleFile",
        "file",
        "bgColor",
        "reminderMins",
        "scheduleMessage",
        "fgColor",
        "font",
        "triggerEvent"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'cancelEvent'
        QtMocHelpers::SlotData<bool(const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'edit'
        QtMocHelpers::SlotData<bool(const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'editNew'
        QtMocHelpers::SlotData<bool(const QString &)>(10, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'editNew'
        QtMocHelpers::SlotData<bool(int)>(10, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'list'
        QtMocHelpers::SlotData<QString()>(13, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'scheduleAudio'
        QtMocHelpers::SlotData<bool(const QString &, int, const QString &, int, uint, int, int, const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 15 }, { QMetaType::Int, 16 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 },
            { QMetaType::UInt, 19 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'scheduleAudio'
        QtMocHelpers::SlotData<bool(const QString &, int, const QString &, int, uint, int, int, int)>(14, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 15 }, { QMetaType::Int, 16 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 },
            { QMetaType::UInt, 19 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 23 },
        }}),
        // Slot 'scheduleAudio'
        QtMocHelpers::SlotData<bool(const QString &, int, const QString &, int, uint, const QString &, int, int)>(14, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 15 }, { QMetaType::Int, 16 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 },
            { QMetaType::UInt, 19 }, { QMetaType::QString, 24 }, { QMetaType::Int, 25 }, { QMetaType::Int, 26 },
        }}),
        // Slot 'scheduleCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, uint, int, int, const QString &)>(27, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::UInt, 19 },
            { QMetaType::Int, 20 }, { QMetaType::Int, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'scheduleCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, uint, int, int, int)>(27, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::UInt, 19 },
            { QMetaType::Int, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 23 },
        }}),
        // Slot 'scheduleCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, uint, const QString &, int, int)>(27, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::UInt, 19 },
            { QMetaType::QString, 24 }, { QMetaType::Int, 25 }, { QMetaType::Int, 26 },
        }}),
        // Slot 'scheduleEmail'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, int, uint, int, int, const QString &)>(29, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 }, { QMetaType::QString, 32 }, { QMetaType::QString, 33 },
            { QMetaType::QString, 34 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::UInt, 19 },
            { QMetaType::Int, 20 }, { QMetaType::Int, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'scheduleEmail'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, int, uint, int, int, int)>(29, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 }, { QMetaType::QString, 32 }, { QMetaType::QString, 33 },
            { QMetaType::QString, 34 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::UInt, 19 },
            { QMetaType::Int, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 23 },
        }}),
        // Slot 'scheduleEmail'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, int, uint, const QString &, int, int)>(29, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 }, { QMetaType::QString, 32 }, { QMetaType::QString, 33 },
            { QMetaType::QString, 34 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::UInt, 19 },
            { QMetaType::QString, 24 }, { QMetaType::Int, 25 }, { QMetaType::Int, 26 },
        }}),
        // Slot 'scheduleFile'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, uint, const QString &, const QString &, int, int, int, const QString &)>(35, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 36 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::UInt, 19 },
            { QMetaType::QString, 37 }, { QMetaType::QString, 15 }, { QMetaType::Int, 38 }, { QMetaType::Int, 20 },
            { QMetaType::Int, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'scheduleFile'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, uint, const QString &, const QString &, int, int, int, int)>(35, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 36 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::UInt, 19 },
            { QMetaType::QString, 37 }, { QMetaType::QString, 15 }, { QMetaType::Int, 38 }, { QMetaType::Int, 20 },
            { QMetaType::Int, 21 }, { QMetaType::Int, 23 },
        }}),
        // Slot 'scheduleFile'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, uint, const QString &, const QString &, int, const QString &, int, int)>(35, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 36 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::UInt, 19 },
            { QMetaType::QString, 37 }, { QMetaType::QString, 15 }, { QMetaType::Int, 38 }, { QMetaType::QString, 24 },
            { QMetaType::Int, 25 }, { QMetaType::Int, 26 },
        }}),
        // Slot 'scheduleMessage'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, uint, const QString &, const QString &, const QString &, const QString &, int, int, int, const QString &)>(39, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 33 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::UInt, 19 },
            { QMetaType::QString, 37 }, { QMetaType::QString, 40 }, { QMetaType::QString, 41 }, { QMetaType::QString, 15 },
            { QMetaType::Int, 38 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'scheduleMessage'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, uint, const QString &, const QString &, const QString &, const QString &, int, int, int, int)>(39, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 33 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::UInt, 19 },
            { QMetaType::QString, 37 }, { QMetaType::QString, 40 }, { QMetaType::QString, 41 }, { QMetaType::QString, 15 },
            { QMetaType::Int, 38 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 23 },
        }}),
        // Slot 'scheduleMessage'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, uint, const QString &, const QString &, const QString &, const QString &, int, const QString &, int, int)>(39, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 33 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::UInt, 19 },
            { QMetaType::QString, 37 }, { QMetaType::QString, 40 }, { QMetaType::QString, 41 }, { QMetaType::QString, 15 },
            { QMetaType::Int, 38 }, { QMetaType::QString, 24 }, { QMetaType::Int, 25 }, { QMetaType::Int, 26 },
        }}),
        // Slot 'triggerEvent'
        QtMocHelpers::SlotData<bool(const QString &)>(42, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KalarmAdaptor, qt_meta_tag_ZN13KalarmAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KalarmAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KalarmAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KalarmAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KalarmAdaptorE_t>.metaTypes,
    nullptr
} };

void KalarmAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KalarmAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->cancelEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->edit((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->editNew((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->editNew((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->list();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->scheduleAudio((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->scheduleAudio((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->scheduleAudio((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->scheduleCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->scheduleCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->scheduleCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->scheduleEmail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[11])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->scheduleEmail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->scheduleEmail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->scheduleFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[10])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->scheduleFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->scheduleFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->scheduleMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[12])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->scheduleMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[12])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->scheduleMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[12])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->triggerEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *KalarmAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KalarmAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KalarmAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KalarmAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}
QT_WARNING_POP
