/********************************************************************************
** Form generated from reading UI file 'wakedlg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WAKEDLG_H
#define UI_WAKEDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_WakeFromSuspendDlgWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QVBoxLayout *verticalLayout1;
    QPushButton *showWakeButton;
    QPushButton *useWakeButton;
    QPushButton *cancelWakeButton;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QSpinBox *advanceWakeTime;
    QLabel *label;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *WakeFromSuspendDlgWidget)
    {
        if (WakeFromSuspendDlgWidget->objectName().isEmpty())
            WakeFromSuspendDlgWidget->setObjectName("WakeFromSuspendDlgWidget");
        WakeFromSuspendDlgWidget->resize(388, 256);
        verticalLayout = new QVBoxLayout(WakeFromSuspendDlgWidget);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(WakeFromSuspendDlgWidget);
        groupBox->setObjectName("groupBox");
        horizontalLayout = new QHBoxLayout(groupBox);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        verticalLayout1 = new QVBoxLayout();
        verticalLayout1->setObjectName("verticalLayout1");
        showWakeButton = new QPushButton(groupBox);
        showWakeButton->setObjectName("showWakeButton");

        verticalLayout1->addWidget(showWakeButton);

        useWakeButton = new QPushButton(groupBox);
        useWakeButton->setObjectName("useWakeButton");

        verticalLayout1->addWidget(useWakeButton);

        cancelWakeButton = new QPushButton(groupBox);
        cancelWakeButton->setObjectName("cancelWakeButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cancelWakeButton->sizePolicy().hasHeightForWidth());
        cancelWakeButton->setSizePolicy(sizePolicy);

        verticalLayout1->addWidget(cancelWakeButton);


        horizontalLayout->addLayout(verticalLayout1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addWidget(groupBox);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        advanceWakeTime = new QSpinBox(WakeFromSuspendDlgWidget);
        advanceWakeTime->setObjectName("advanceWakeTime");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(advanceWakeTime->sizePolicy().hasHeightForWidth());
        advanceWakeTime->setSizePolicy(sizePolicy1);
        advanceWakeTime->setMaximum(10);

        horizontalLayout_2->addWidget(advanceWakeTime);

        label = new QLabel(WakeFromSuspendDlgWidget);
        label->setObjectName("label");

        horizontalLayout_2->addWidget(label);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(WakeFromSuspendDlgWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(WakeFromSuspendDlgWidget);

        QMetaObject::connectSlotsByName(WakeFromSuspendDlgWidget);
    } // setupUi

    void retranslateUi(QWidget *WakeFromSuspendDlgWidget)
    {
        groupBox->setTitle(tr2i18n("Wake From Suspend Alarm", nullptr));
#if QT_CONFIG(tooltip)
        showWakeButton->setToolTip(tr2i18n("Show current wake-from-suspend alarm", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        showWakeButton->setWhatsThis(tr2i18n("Highlight the current wake-from-suspend alarm in the alarm list. This button is disabled if no wake-from-suspend alarm is configured.", nullptr));
#endif // QT_CONFIG(whatsthis)
        showWakeButton->setText(tr2i18n("Show current alarm", nullptr));
#if QT_CONFIG(tooltip)
        useWakeButton->setToolTip(tr2i18n("Set highlighted alarm as the wake-from-suspend alarm", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        useWakeButton->setWhatsThis(tr2i18n("Set the alarm highlighted in the alarm list to wake-from-suspend. This replaces any existing wake-from-suspend alarm.", nullptr));
#endif // QT_CONFIG(whatsthis)
        useWakeButton->setText(tr2i18n("Use highlighted alarm", nullptr));
#if QT_CONFIG(tooltip)
        cancelWakeButton->setToolTip(tr2i18n("Cancel the current wake-from-suspend", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        cancelWakeButton->setWhatsThis(tr2i18n("Cancel the currently configured wake-from-suspend. Note that this does not cancel the alarm itself, which will still trigger in the normal way. This button is disabled if no wake-from-suspend alarm is configured.", nullptr));
#endif // QT_CONFIG(whatsthis)
        cancelWakeButton->setText(tr2i18n("Cancel wake from suspend", nullptr));
#if QT_CONFIG(whatsthis)
        advanceWakeTime->setWhatsThis(tr2i18n("Enter how many minutes before the alarm trigger time to wake the system from suspend. This can be used to ensure that the system is fully restored by the time the alarm triggers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("Number of minutes before alarm to wake from suspend", nullptr));
        (void)WakeFromSuspendDlgWidget;
    } // retranslateUi

};

namespace Ui {
    class WakeFromSuspendDlgWidget: public Ui_WakeFromSuspendDlgWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WAKEDLG_H

