/****************************************************************************
** Meta object code from reading C++ file 'daymatrix.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/daymatrix.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'daymatrix.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9DayMatrixE_t {};
} // unnamed namespace

template <> constexpr inline auto DayMatrix::qt_create_metaobjectdata<qt_meta_tag_ZN9DayMatrixE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DayMatrix",
        "selected",
        "",
        "QList<QDate>",
        "dates",
        "workChange",
        "newAlarm",
        "EditAlarmDlg::Type",
        "newAlarmFromTemplate",
        "KAlarmCal::KAEvent",
        "resourceUpdated",
        "Resource&",
        "resourceRemoved",
        "KAlarmCal::ResourceId",
        "resourceSettingsChanged",
        "ResourceType::Changes",
        "slotUpdateView"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selected'
        QtMocHelpers::SignalData<void(const QList<QDate> &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'newAlarm'
        QtMocHelpers::SignalData<void(EditAlarmDlg::Type)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'newAlarmFromTemplate'
        QtMocHelpers::SignalData<void(const KAlarmCal::KAEvent &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Slot 'resourceUpdated'
        QtMocHelpers::SlotData<void(Resource &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'resourceRemoved'
        QtMocHelpers::SlotData<void(KAlarmCal::ResourceId)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'resourceSettingsChanged'
        QtMocHelpers::SlotData<void(Resource &, ResourceType::Changes)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 2 }, { 0x80000000 | 15, 2 },
        }}),
        // Slot 'slotUpdateView'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DayMatrix, qt_meta_tag_ZN9DayMatrixE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DayMatrix::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DayMatrixE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DayMatrixE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9DayMatrixE_t>.metaTypes,
    nullptr
} };

void DayMatrix::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DayMatrix *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selected((*reinterpret_cast<std::add_pointer_t<QList<QDate>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->newAlarm((*reinterpret_cast<std::add_pointer_t<EditAlarmDlg::Type>>(_a[1]))); break;
        case 2: _t->newAlarmFromTemplate((*reinterpret_cast<std::add_pointer_t<KAlarmCal::KAEvent>>(_a[1]))); break;
        case 3: _t->resourceUpdated((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1]))); break;
        case 4: _t->resourceRemoved((*reinterpret_cast<std::add_pointer_t<KAlarmCal::ResourceId>>(_a[1]))); break;
        case 5: _t->resourceSettingsChanged((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ResourceType::Changes>>(_a[2]))); break;
        case 6: _t->slotUpdateView(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDate> >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KAlarmCal::KAEvent >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DayMatrix::*)(const QList<QDate> & , bool )>(_a, &DayMatrix::selected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DayMatrix::*)(EditAlarmDlg::Type )>(_a, &DayMatrix::newAlarm, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DayMatrix::*)(const KAlarmCal::KAEvent & )>(_a, &DayMatrix::newAlarmFromTemplate, 2))
            return;
    }
}

const QMetaObject *DayMatrix::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DayMatrix::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DayMatrixE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int DayMatrix::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void DayMatrix::selected(const QList<QDate> & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void DayMatrix::newAlarm(EditAlarmDlg::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DayMatrix::newAlarmFromTemplate(const KAlarmCal::KAEvent & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
