/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // kalarmui.rc
  0x0,0x0,0x2,0x91,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x32,0xa,0x3d,0x14,0x0,0x56,0x9c,0x51,0x1e,0x30,0x73,0x73,
  0xcf,0x20,0x49,0x80,0xc9,0x5a,0x2f,0x65,0x2d,0x6f,0xbc,0x4b,0xe7,0x9b,0x3a,0xe4,
  0x6e,0xd1,0xef,0xdc,0x4c,0x6b,0x96,0x11,0x21,0xc0,0x13,0x4c,0x0,0x47,0x0,0x48,
  0x0,0x7f,0xdf,0xbd,0x51,0xda,0xd6,0x62,0xd0,0xe7,0xda,0x49,0xc0,0xdb,0xc9,0x79,
  0x5d,0x12,0x30,0xa8,0xf3,0xf7,0x56,0x7b,0x42,0x44,0xec,0x69,0x5a,0x10,0xa1,0xe2,
  0x43,0xf6,0x31,0xce,0x84,0xdb,0xa5,0x44,0xc,0x70,0x60,0xd0,0xa0,0x50,0x80,0xc,
  0x6f,0x15,0xf2,0x39,0xc,0xb2,0x38,0x5d,0x6e,0x20,0xc3,0xad,0x7c,0x4c,0x63,0x15,
  0x1,0xe,0x1a,0x2b,0xc6,0x90,0x5c,0x28,0x8a,0xc8,0x22,0x10,0x5,0x18,0xf6,0xe6,
  0x5c,0x62,0x7a,0xba,0x3b,0x6c,0x6d,0xc,0x41,0xe4,0xf9,0x27,0x9b,0xa6,0x59,0x13,
  0x16,0xa7,0x43,0x34,0xef,0x65,0x29,0xec,0x77,0xba,0xcb,0x3a,0xe5,0x9d,0x67,0x41,
  0x74,0xa7,0x8d,0x43,0x7b,0xde,0x11,0xbb,0x53,0x2a,0xbe,0x43,0x4,0x51,0x7c,0xb7,
  0x30,0xfc,0x8a,0x63,0xc6,0x4a,0xcd,0xa7,0xbc,0xa0,0xf6,0x94,0x3a,0x33,0x68,0xdb,
  0x8b,0x98,0xd6,0x16,0x19,0xcc,0xb5,0x52,0xf5,0xb4,0xfb,0x70,0xb5,0x45,0xc4,0xb5,
  0xdd,0xde,0x2f,0x18,0xa5,0x6f,0xb2,0xa3,0x81,0x67,0xea,0xfc,0x18,0x79,0xe9,0x6,
  0xba,0x4c,0x42,0x7d,0x11,0xc2,0x6c,0x79,0xbe,0x78,0xa5,0x77,0x2e,0x3e,0x71,0x5c,
  0xf8,0x49,0x32,0xc5,0x7a,0xc3,0x8f,0xf4,0x1e,0xed,0x1c,0xd5,0x4c,0x8c,0xe8,0xac,
  0x6,0x76,0xae,0x96,0xce,0x95,0xc3,0x39,0x5f,0xed,0xf9,0xb,0x80,0x83,0xc6,0x4a,
  0x10,0x59,0x8f,0x86,0xe0,0xbc,0x53,0x70,0x5c,0xb7,0x8a,0xbe,0xd4,0x2e,0x26,0xb5,
  0x56,0xbb,0x2a,0xd0,0x69,0xf6,0x17,0x9c,0x94,0xd6,0x7d,0xc2,0x6f,0x15,0xd,0xd5,
  0x71,0x66,0xdc,0x6e,0xe7,0xa4,0x94,0xf6,0x3e,0x6,0x55,0x4f,0xdb,0xd3,0xcc,0xe7,
  0x1b,0xcc,0x39,0x56,0x4a,0xbd,0x9d,0xee,0xda,0x4b,0x47,0xe3,0x6c,0x2f,0x5b,0x82,
  0x38,0x3,0x80,0x85,0xa0,0xc1,0x99,0x23,0xa6,0x66,0x48,0x9a,0x64,0x63,0x37,0x20,
  0x46,0x40,0x8c,0x54,0xa3,0x1d,0xc4,0x27,0x2a,0x50,0x35,0x2d,0x83,0x20,0x2d,0x5b,
  0xbd,0x33,0xc8,0x48,0x29,0xc1,0x86,0x72,0xa9,0x9e,0x75,0x9,0x17,0x94,0x5c,0xb9,
  0x69,0xcf,0x3c,0xc3,0x1a,0x6b,0x5,0xd,0x60,0x37,0xad,0x51,0x48,0xb,0x44,0x9f,
  0xa,0x91,0xb9,0xd,0x65,0xcb,0x7,0x31,0xcb,0xa4,0xee,0x69,0xb2,0x4f,0x4b,0xac,
  0x42,0x83,0xb2,0x3c,0xdf,0xf1,0x2d,0xde,0x4d,0x26,0xd1,0x21,0xe3,0x47,0x2c,0x2b,
  0x2c,0xef,0x54,0xa9,0xcc,0xac,0x2d,0x47,0x77,0xce,0xcb,0xb1,0x16,0xdd,0x5,0xde,
  0xfa,0xc7,0xfa,0x65,0x56,0x68,0xfd,0x50,0x61,0x5c,0x33,0x5f,0xcf,0xca,0x6b,0xa1,
  0x94,0xc3,0x32,0x65,0xeb,0xa,0xb2,0xfb,0x62,0x85,0xb,0xf1,0x2c,0x55,0xa9,0x1c,
  0xcc,0x3,0x71,0x45,0x2c,0x85,0xfd,0xc8,0x24,0xb3,0x3c,0x5b,0x53,0x63,0xe1,0xff,
  0x7a,0x1a,0x50,0xfd,0x9,0x55,0x66,0x94,0x5d,0x84,0xd7,0x83,0xa1,0x1d,0x3c,0x4d,
  0x5c,0xb5,0x30,0xb7,0x62,0x61,0x2a,0xb,0xcf,0x11,0xce,0xaf,0x23,0xba,0xa9,0xb,
  0x5d,0xa2,0x7,0x59,0x92,0xc5,0x8d,0x9c,0x9c,0xd9,0x32,0x53,0xf0,0x8c,0xab,0xd8,
  0xfd,0xd7,0xec,0xb6,0x14,0x14,0xe,0xe0,0xc7,0x81,0x1e,0xd7,0x25,0xef,0xb0,0x78,
  0x7f,0x95,0x5d,0xc3,0x68,0x1d,0x78,0xe3,0xd0,0xe8,0x86,0x3e,0xc4,0x31,0x1a,0x19,
  0x49,0xa0,0x6e,0x28,0xb8,0x38,0x0,0x85,0x79,0xd1,0xf5,0x29,0x7b,0x3b,0x20,0xf5,
  0x91,0x2c,0x79,0x79,0x34,0xa2,0x4d,0x7d,0x30,0xb5,0x2d,0xc,0x35,0xce,0x3b,0x5c,
  0xa3,0x25,0x70,0xbd,0x32,0x30,0xdc,0x65,0xbe,0x0,0x16,0xf2,0x8e,0xb7,0xcf,0xa4,
  0xf3,0xe4,0xee,0x9c,0x7,0x2e,0x16,0x2,0xce,0xa1,0x90,0xe0,0xa3,0x10,0x26,0xd9,
  0x55,0x3b,0x5a,0xda,0x16,0xed,0x58,0x6c,0x20,0xf7,0x92,0x85,0x82,0x3,0x68,0x15,
  
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // kalarm
  0x0,0x6,
  0x7,0x18,0x28,0x8d,
  0x0,0x6b,
  0x0,0x61,0x0,0x6c,0x0,0x61,0x0,0x72,0x0,0x6d,
    // kalarmui.rc
  0x0,0xb,
  0x9,0xa8,0xc0,0x83,
  0x0,0x6b,
  0x0,0x61,0x0,0x6c,0x0,0x61,0x0,0x72,0x0,0x6d,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9d,0x79,0x24,0xd0,0x48,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9d,0x79,0x24,0xd0,0x48,
  // :/kxmlgui5/kalarm
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9d,0x79,0x24,0xd0,0x48,
  // :/kxmlgui5/kalarm/kalarmui.rc
  0x0,0x0,0x0,0x28,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9d,0x79,0x24,0xd0,0x48,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kalarm)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kalarm)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kalarm)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kalarm)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kalarm)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kalarm)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
