/****************************************************************************
** Meta object code from reading C++ file 'dbushandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/dbushandler.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbushandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11DBusHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusHandler::qt_create_metaobjectdata<qt_meta_tag_ZN11DBusHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusHandler",
        "D-Bus Interface",
        "org.kde.kalarm.kalarm",
        "cancelEvent",
        "",
        "eventId",
        "triggerEvent",
        "list",
        "scheduleMessage",
        "name",
        "message",
        "startDateTime",
        "lateCancel",
        "flags",
        "bgColor",
        "fgColor",
        "font",
        "audioUrl",
        "reminderMins",
        "recurrence",
        "subRepeatInterval",
        "subRepeatCount",
        "recurType",
        "recurInterval",
        "recurCount",
        "endDateTime",
        "scheduleFile",
        "url",
        "scheduleCommand",
        "commandLine",
        "scheduleEmail",
        "fromID",
        "addresses",
        "subject",
        "attachments",
        "scheduleAudio",
        "volumePercent",
        "edit",
        "eventID",
        "editNew",
        "type",
        "templateName"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'cancelEvent'
        QtMocHelpers::SlotData<bool(const QString &)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'triggerEvent'
        QtMocHelpers::SlotData<bool(const QString &)>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'list'
        QtMocHelpers::SlotData<QString()>(7, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'scheduleMessage'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, int, unsigned , const QString &, const QString &, const QString &, const QString &, int, const QString &, int, int)>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::QString, 14 }, { QMetaType::QString, 15 }, { QMetaType::QString, 16 },
            { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::QString, 19 }, { QMetaType::Int, 20 },
            { QMetaType::Int, 21 },
        }}),
        // Slot 'scheduleMessage'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, int, unsigned , const QString &, const QString &, const QString &, const QString &, int, int, int, int)>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::QString, 14 }, { QMetaType::QString, 15 }, { QMetaType::QString, 16 },
            { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 },
            { QMetaType::Int, 24 },
        }}),
        // Slot 'scheduleMessage'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, int, unsigned , const QString &, const QString &, const QString &, const QString &, int, int, int, const QString &)>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::QString, 14 }, { QMetaType::QString, 15 }, { QMetaType::QString, 16 },
            { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 },
            { QMetaType::QString, 25 },
        }}),
        // Slot 'scheduleMessage'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, unsigned , const QString &, const QString &, const QString &, const QString &, int, const QString &, int, int)>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 }, { QMetaType::UInt, 13 },
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
            { QMetaType::Int, 18 }, { QMetaType::QString, 19 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'scheduleMessage'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, unsigned , const QString &, const QString &, const QString &, const QString &, int, int, int, int)>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 }, { QMetaType::UInt, 13 },
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
            { QMetaType::Int, 18 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'scheduleMessage'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, unsigned , const QString &, const QString &, const QString &, const QString &, int, int, int, const QString &)>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 }, { QMetaType::UInt, 13 },
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
            { QMetaType::Int, 18 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'scheduleFile'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, int, unsigned , const QString &, const QString &, int, const QString &, int, int)>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 27 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::QString, 14 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 },
            { QMetaType::QString, 19 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'scheduleFile'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, int, unsigned , const QString &, const QString &, int, int, int, int)>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 27 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::QString, 14 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 },
            { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'scheduleFile'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, int, unsigned , const QString &, const QString &, int, int, int, const QString &)>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 27 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::QString, 14 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 },
            { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'scheduleFile'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, unsigned , const QString &, const QString &, int, const QString &, int, int)>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 }, { QMetaType::UInt, 13 },
            { QMetaType::QString, 14 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::QString, 19 },
            { QMetaType::Int, 20 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'scheduleFile'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, unsigned , const QString &, const QString &, int, int, int, int)>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 }, { QMetaType::UInt, 13 },
            { QMetaType::QString, 14 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 22 },
            { QMetaType::Int, 23 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'scheduleFile'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, unsigned , const QString &, const QString &, int, int, int, const QString &)>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 }, { QMetaType::UInt, 13 },
            { QMetaType::QString, 14 }, { QMetaType::QString, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 22 },
            { QMetaType::Int, 23 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'scheduleCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, int, unsigned , const QString &, int, int)>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 29 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::QString, 19 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'scheduleCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, int, unsigned , int, int, int)>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 29 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'scheduleCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, int, unsigned , int, int, const QString &)>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 29 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'scheduleCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, unsigned , const QString &, int, int)>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 }, { QMetaType::UInt, 13 },
            { QMetaType::QString, 19 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'scheduleCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, unsigned , int, int, int)>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 }, { QMetaType::UInt, 13 },
            { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'scheduleCommand'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, unsigned , int, int, const QString &)>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 29 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 }, { QMetaType::UInt, 13 },
            { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'scheduleEmail'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, int, unsigned , const QString &, int, int)>(30, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 31 }, { QMetaType::QString, 32 }, { QMetaType::QString, 33 },
            { QMetaType::QString, 10 }, { QMetaType::QString, 34 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::QString, 19 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'scheduleEmail'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, int, unsigned , int, int, int)>(30, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 31 }, { QMetaType::QString, 32 }, { QMetaType::QString, 33 },
            { QMetaType::QString, 10 }, { QMetaType::QString, 34 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'scheduleEmail'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, int, unsigned , int, int, const QString &)>(30, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 31 }, { QMetaType::QString, 32 }, { QMetaType::QString, 33 },
            { QMetaType::QString, 10 }, { QMetaType::QString, 34 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'scheduleEmail'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, int, unsigned , const QString &, int, int)>(30, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 31 }, { QMetaType::QString, 32 }, { QMetaType::QString, 33 }, { QMetaType::QString, 10 },
            { QMetaType::QString, 34 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 }, { QMetaType::UInt, 13 },
            { QMetaType::QString, 19 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'scheduleEmail'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, int, unsigned , int, int, int)>(30, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 31 }, { QMetaType::QString, 32 }, { QMetaType::QString, 33 }, { QMetaType::QString, 10 },
            { QMetaType::QString, 34 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 }, { QMetaType::UInt, 13 },
            { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'scheduleEmail'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, int, unsigned , int, int, const QString &)>(30, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 31 }, { QMetaType::QString, 32 }, { QMetaType::QString, 33 }, { QMetaType::QString, 10 },
            { QMetaType::QString, 34 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 }, { QMetaType::UInt, 13 },
            { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'scheduleAudio'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, const QString &, int, unsigned , const QString &, int, int)>(35, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 17 }, { QMetaType::Int, 36 }, { QMetaType::QString, 11 },
            { QMetaType::Int, 12 }, { QMetaType::UInt, 13 }, { QMetaType::QString, 19 }, { QMetaType::Int, 20 },
            { QMetaType::Int, 21 },
        }}),
        // Slot 'scheduleAudio'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, const QString &, int, unsigned , int, int, int)>(35, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 17 }, { QMetaType::Int, 36 }, { QMetaType::QString, 11 },
            { QMetaType::Int, 12 }, { QMetaType::UInt, 13 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 },
            { QMetaType::Int, 24 },
        }}),
        // Slot 'scheduleAudio'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, int, const QString &, int, unsigned , int, int, const QString &)>(35, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 17 }, { QMetaType::Int, 36 }, { QMetaType::QString, 11 },
            { QMetaType::Int, 12 }, { QMetaType::UInt, 13 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 },
            { QMetaType::QString, 25 },
        }}),
        // Slot 'scheduleAudio'
        QtMocHelpers::SlotData<bool(const QString &, int, const QString &, int, unsigned , const QString &, int, int)>(35, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 17 }, { QMetaType::Int, 36 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::QString, 19 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'scheduleAudio'
        QtMocHelpers::SlotData<bool(const QString &, int, const QString &, int, unsigned , int, int, int)>(35, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 17 }, { QMetaType::Int, 36 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'scheduleAudio'
        QtMocHelpers::SlotData<bool(const QString &, int, const QString &, int, unsigned , int, int, const QString &)>(35, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 17 }, { QMetaType::Int, 36 }, { QMetaType::QString, 11 }, { QMetaType::Int, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'edit'
        QtMocHelpers::SlotData<bool(const QString &)>(37, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 38 },
        }}),
        // Slot 'editNew'
        QtMocHelpers::SlotData<bool(int)>(39, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 40 },
        }}),
        // Slot 'editNew'
        QtMocHelpers::SlotData<bool(const QString &)>(39, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 41 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DBusHandler, qt_meta_tag_ZN11DBusHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DBusHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DBusHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DBusHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11DBusHandlerE_t>.metaTypes,
    nullptr
} };

void DBusHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->cancelEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->triggerEvent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->list();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->scheduleMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[13])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->scheduleMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[13])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->scheduleMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[13])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->scheduleMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[12])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->scheduleMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[12])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->scheduleMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[12])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->scheduleFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->scheduleFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->scheduleFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[11])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->scheduleFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->scheduleFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->scheduleFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[10])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->scheduleCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->scheduleCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->scheduleCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->scheduleCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->scheduleCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->scheduleCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->scheduleEmail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[12])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->scheduleEmail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[12])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->scheduleEmail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[12])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->scheduleEmail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->scheduleEmail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[11])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->scheduleEmail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[11])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->scheduleAudio((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->scheduleAudio((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[9])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->scheduleAudio((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[9])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->scheduleAudio((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->scheduleAudio((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->scheduleAudio((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[8])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->edit((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->editNew((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: { bool _r = _t->editNew((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *DBusHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DBusHandlerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KAlarmIface"))
        return static_cast< KAlarmIface*>(this);
    return QObject::qt_metacast(_clname);
}

int DBusHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 36)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 36;
    }
    return _id;
}
QT_WARNING_POP
