/****************************************************************************
** Meta object code from reading C++ file 'resourcescalendar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/resourcescalendar.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resourcescalendar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17ResourcesCalendarE_t {};
} // unnamed namespace

template <> constexpr inline auto ResourcesCalendar::qt_create_metaobjectdata<qt_meta_tag_ZN17ResourcesCalendarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ResourcesCalendar",
        "earliestAlarmChanged",
        "",
        "haveDisabledAlarmsChanged",
        "haveDisabled",
        "atLoginEventAdded",
        "KAlarmCal::KAEvent",
        "slotResourceSettingsChanged",
        "Resource&",
        "ResourceType::Changes",
        "slotResourcesPopulated",
        "slotResourceAdded",
        "slotEventsAdded",
        "QList<KAlarmCal::KAEvent>",
        "slotEventsToBeRemoved",
        "slotEventUpdated",
        "slotAlarmsEnabledToggled",
        "enabled",
        "slotWakeFromSuspendAdvanceChanged",
        "advance"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'earliestAlarmChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'haveDisabledAlarmsChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'atLoginEventAdded'
        QtMocHelpers::SignalData<void(const KAlarmCal::KAEvent &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotResourceSettingsChanged'
        QtMocHelpers::SlotData<void(Resource &, ResourceType::Changes)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 }, { 0x80000000 | 9, 2 },
        }}),
        // Slot 'slotResourcesPopulated'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResourceAdded'
        QtMocHelpers::SlotData<void(Resource &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'slotEventsAdded'
        QtMocHelpers::SlotData<void(Resource &, const QList<KAlarmCal::KAEvent> &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 }, { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotEventsToBeRemoved'
        QtMocHelpers::SlotData<void(Resource &, const QList<KAlarmCal::KAEvent> &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 }, { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotEventUpdated'
        QtMocHelpers::SlotData<void(Resource &, const KAlarmCal::KAEvent &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 }, { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotAlarmsEnabledToggled'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'slotWakeFromSuspendAdvanceChanged'
        QtMocHelpers::SlotData<void(unsigned )>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ResourcesCalendar, qt_meta_tag_ZN17ResourcesCalendarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ResourcesCalendar::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ResourcesCalendarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ResourcesCalendarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17ResourcesCalendarE_t>.metaTypes,
    nullptr
} };

void ResourcesCalendar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ResourcesCalendar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->earliestAlarmChanged(); break;
        case 1: _t->haveDisabledAlarmsChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->atLoginEventAdded((*reinterpret_cast<std::add_pointer_t<KAlarmCal::KAEvent>>(_a[1]))); break;
        case 3: _t->slotResourceSettingsChanged((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ResourceType::Changes>>(_a[2]))); break;
        case 4: _t->slotResourcesPopulated(); break;
        case 5: _t->slotResourceAdded((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1]))); break;
        case 6: _t->slotEventsAdded((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<KAlarmCal::KAEvent>>>(_a[2]))); break;
        case 7: _t->slotEventsToBeRemoved((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<KAlarmCal::KAEvent>>>(_a[2]))); break;
        case 8: _t->slotEventUpdated((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KAlarmCal::KAEvent>>(_a[2]))); break;
        case 9: _t->slotAlarmsEnabledToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->slotWakeFromSuspendAdvanceChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KAlarmCal::KAEvent >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<KAlarmCal::KAEvent> >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<KAlarmCal::KAEvent> >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KAlarmCal::KAEvent >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ResourcesCalendar::*)()>(_a, &ResourcesCalendar::earliestAlarmChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesCalendar::*)(bool )>(_a, &ResourcesCalendar::haveDisabledAlarmsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourcesCalendar::*)(const KAlarmCal::KAEvent & )>(_a, &ResourcesCalendar::atLoginEventAdded, 2))
            return;
    }
}

const QMetaObject *ResourcesCalendar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ResourcesCalendar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ResourcesCalendarE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ResourcesCalendar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void ResourcesCalendar::earliestAlarmChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ResourcesCalendar::haveDisabledAlarmsChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ResourcesCalendar::atLoginEventAdded(const KAlarmCal::KAEvent & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
