/****************************************************************************
** Meta object code from reading C++ file 'kmailinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "kmailinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmailinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25OrgKdeKmailKmailInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeKmailKmailInterface::qt_create_metaobjectdata<qt_meta_tag_ZN25OrgKdeKmailKmailInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeKmailKmailInterface",
        "accounts",
        "QDBusPendingReply<QStringList>",
        "",
        "canQueryClose",
        "QDBusPendingReply<bool>",
        "checkAccount",
        "QDBusPendingReply<>",
        "account",
        "checkMail",
        "handleCommandLine",
        "noArgsOpensReader",
        "args",
        "workingDir",
        "newMessage",
        "to",
        "cc",
        "bcc",
        "hidden",
        "useFolderId",
        "messageFile",
        "attachURL",
        "openComposer",
        "subject",
        "body",
        "attachName",
        "attachCte",
        "attachData",
        "attachType",
        "attachSubType",
        "attachParamAttr",
        "attachParamValue",
        "attachContDisp",
        "attachCharset",
        "identity",
        "attachmentPaths",
        "customHeaders",
        "replyTo",
        "inReplyTo",
        "openReader",
        "pauseBackgroundJobs",
        "reloadFolderArchiveConfig",
        "resumeBackgroundJobs",
        "resumeNetworkJobs",
        "selectFolder",
        "folder",
        "showFolder",
        "collectionId",
        "showMail",
        "serialNumber",
        "stopNetworkJobs",
        "updateConfig",
        "viewMessage",
        "QDBusPendingReply<int>"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'accounts'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'canQueryClose'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(4, 3, QMC::AccessPublic, 0x80000000 | 5),
        // Slot 'checkAccount'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(6, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'checkMail'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(9, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'handleCommandLine'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(bool, const QStringList &, const QString &)>(10, 3, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::Bool, 11 }, { QMetaType::QStringList, 12 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'newMessage'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &, bool, bool, const QString &, const QString &)>(14, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::Bool, 18 },
            { QMetaType::Bool, 19 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'openComposer'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &, const QString &, const QString &, bool)>(22, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 23 },
            { QMetaType::QString, 24 }, { QMetaType::Bool, 18 },
        }}),
        // Slot 'openComposer'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &, const QByteArray &, const QByteArray &, const QByteArray &, const QByteArray &, const QByteArray &, const QString &, const QByteArray &, const QByteArray &, uint)>(22, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 23 },
            { QMetaType::QString, 24 }, { QMetaType::QString, 25 }, { QMetaType::QByteArray, 26 }, { QMetaType::QByteArray, 27 },
            { QMetaType::QByteArray, 28 }, { QMetaType::QByteArray, 29 }, { QMetaType::QByteArray, 30 }, { QMetaType::QString, 31 },
            { QMetaType::QByteArray, 32 }, { QMetaType::QByteArray, 33 }, { QMetaType::UInt, 34 },
        }}),
        // Slot 'openComposer'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &, const QString &, const QString &, bool, const QString &, const QByteArray &, const QByteArray &, const QByteArray &, const QByteArray &, const QByteArray &, const QString &, const QByteArray &, const QByteArray &, uint)>(22, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 23 },
            { QMetaType::QString, 24 }, { QMetaType::Bool, 18 }, { QMetaType::QString, 25 }, { QMetaType::QByteArray, 26 },
            { QMetaType::QByteArray, 27 }, { QMetaType::QByteArray, 28 }, { QMetaType::QByteArray, 29 }, { QMetaType::QByteArray, 30 },
            { QMetaType::QString, 31 }, { QMetaType::QByteArray, 32 }, { QMetaType::QByteArray, 33 }, { QMetaType::UInt, 34 },
        }}),
        // Slot 'openComposer'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &, const QString &, const QString &, bool, const QString &, const QStringList &, const QStringList &)>(22, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 23 },
            { QMetaType::QString, 24 }, { QMetaType::Bool, 18 }, { QMetaType::QString, 20 }, { QMetaType::QStringList, 35 },
            { QMetaType::QStringList, 36 },
        }}),
        // Slot 'openComposer'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &, const QString &, const QString &, bool, const QString &, const QStringList &, const QStringList &, const QString &)>(22, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 23 },
            { QMetaType::QString, 24 }, { QMetaType::Bool, 18 }, { QMetaType::QString, 20 }, { QMetaType::QStringList, 35 },
            { QMetaType::QStringList, 36 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'openComposer'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &, const QString &, const QString &, bool, const QString &, const QStringList &, const QStringList &, const QString &, const QString &)>(22, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 23 },
            { QMetaType::QString, 24 }, { QMetaType::Bool, 18 }, { QMetaType::QString, 20 }, { QMetaType::QStringList, 35 },
            { QMetaType::QStringList, 36 }, { QMetaType::QString, 37 }, { QMetaType::QString, 38 },
        }}),
        // Slot 'openComposer'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &, const QString &, const QString &, bool, const QString &, const QStringList &, const QStringList &, const QString &, const QString &, const QString &)>(22, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 23 },
            { QMetaType::QString, 24 }, { QMetaType::Bool, 18 }, { QMetaType::QString, 20 }, { QMetaType::QStringList, 35 },
            { QMetaType::QStringList, 36 }, { QMetaType::QString, 37 }, { QMetaType::QString, 38 }, { QMetaType::QString, 34 },
        }}),
        // Slot 'openReader'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(39, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'pauseBackgroundJobs'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(40, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'reloadFolderArchiveConfig'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(41, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'resumeBackgroundJobs'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(42, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'resumeNetworkJobs'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(43, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'selectFolder'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(44, 3, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::QString, 45 },
        }}),
        // Slot 'showFolder'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(46, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 47 },
        }}),
        // Slot 'showMail'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(qlonglong)>(48, 3, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::LongLong, 49 },
        }}),
        // Slot 'stopNetworkJobs'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(50, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'updateConfig'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(51, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'viewMessage'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(const QString &)>(52, 3, QMC::AccessPublic, 0x80000000 | 53, {{
            { QMetaType::QString, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeKmailKmailInterface, qt_meta_tag_ZN25OrgKdeKmailKmailInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeKmailKmailInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25OrgKdeKmailKmailInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25OrgKdeKmailKmailInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25OrgKdeKmailKmailInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeKmailKmailInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeKmailKmailInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<QStringList> _r = _t->accounts();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<bool> _r = _t->canQueryClose();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->checkAccount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->checkMail();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<bool> _r = _t->handleCommandLine((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->newMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->openComposer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->openComposer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[13])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[14])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[15])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->openComposer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[12])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[13])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[14])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[15])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[16])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->openComposer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[9])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->openComposer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[10])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->openComposer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[11])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->openComposer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[9])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[10])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[11])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[12])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->openReader();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<> _r = _t->pauseBackgroundJobs();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<> _r = _t->reloadFolderArchiveConfig();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<> _r = _t->resumeBackgroundJobs();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->resumeNetworkJobs();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<bool> _r = _t->selectFolder((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->showFolder((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<bool> _r = _t->showMail((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->stopNetworkJobs();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->updateConfig();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<int> _r = _t->viewMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *OrgKdeKmailKmailInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeKmailKmailInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25OrgKdeKmailKmailInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeKmailKmailInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    return _id;
}
QT_WARNING_POP
