/****************************************************************************
** Meta object code from reading C++ file 'recurrenceedit.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/recurrenceedit.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'recurrenceedit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14RecurrenceEditE_t {};
} // unnamed namespace

template <> constexpr inline auto RecurrenceEdit::qt_create_metaobjectdata<qt_meta_tag_ZN14RecurrenceEditE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RecurrenceEdit",
        "shown",
        "",
        "typeChanged",
        "recurType",
        "frequencyChanged",
        "repeatNeedsInitialisation",
        "contentsChanged",
        "setDateTime",
        "KADateTime",
        "start",
        "periodClicked",
        "QAbstractButton*",
        "rangeTypeClicked",
        "repeatCountChanged",
        "value",
        "slotAnyTimeToggled",
        "addException",
        "changeException",
        "deleteException",
        "enableExceptionButtons"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'shown'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'frequencyChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'repeatNeedsInitialisation'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentsChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDateTime'
        QtMocHelpers::SlotData<void(const KADateTime &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'periodClicked'
        QtMocHelpers::SlotData<void(QAbstractButton *, QAbstractButton *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 2 }, { 0x80000000 | 12, 2 },
        }}),
        // Slot 'rangeTypeClicked'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'repeatCountChanged'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'slotAnyTimeToggled'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'addException'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeException'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteException'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enableExceptionButtons'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RecurrenceEdit, qt_meta_tag_ZN14RecurrenceEditE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RecurrenceEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14RecurrenceEditE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14RecurrenceEditE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14RecurrenceEditE_t>.metaTypes,
    nullptr
} };

void RecurrenceEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RecurrenceEdit *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->shown(); break;
        case 1: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->frequencyChanged(); break;
        case 3: _t->repeatNeedsInitialisation(); break;
        case 4: _t->contentsChanged(); break;
        case 5: _t->setDateTime((*reinterpret_cast<std::add_pointer_t<KADateTime>>(_a[1]))); break;
        case 6: _t->periodClicked((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[2]))); break;
        case 7: _t->rangeTypeClicked(); break;
        case 8: _t->repeatCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->slotAnyTimeToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->addException(); break;
        case 11: _t->changeException(); break;
        case 12: _t->deleteException(); break;
        case 13: _t->enableExceptionButtons(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RecurrenceEdit::*)()>(_a, &RecurrenceEdit::shown, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecurrenceEdit::*)(int )>(_a, &RecurrenceEdit::typeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecurrenceEdit::*)()>(_a, &RecurrenceEdit::frequencyChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecurrenceEdit::*)()>(_a, &RecurrenceEdit::repeatNeedsInitialisation, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecurrenceEdit::*)()>(_a, &RecurrenceEdit::contentsChanged, 4))
            return;
    }
}

const QMetaObject *RecurrenceEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RecurrenceEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14RecurrenceEditE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int RecurrenceEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void RecurrenceEdit::shown()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void RecurrenceEdit::typeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void RecurrenceEdit::frequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void RecurrenceEdit::repeatNeedsInitialisation()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void RecurrenceEdit::contentsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
