/****************************************************************************
** Meta object code from reading C++ file 'resources.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/resources/resources.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resources.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9ResourcesE_t {};
} // unnamed namespace

template <> constexpr inline auto Resources::qt_create_metaobjectdata<qt_meta_tag_ZN9ResourcesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Resources",
        "settingsChanged",
        "",
        "Resource&",
        "ResourceType::Changes",
        "resourcesCreated",
        "resourcesPopulated",
        "resourceAdded",
        "resourcePopulated",
        "resourceToBeRemoved",
        "resourceRemoved",
        "KAlarmCal::ResourceId",
        "resourceMessage",
        "ResourceType::MessageType",
        "message",
        "details",
        "eventsAdded",
        "QList<KAEvent>",
        "eventUpdated",
        "KAEvent",
        "eventsToBeRemoved",
        "eventsRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'settingsChanged'
        QtMocHelpers::SignalData<void(Resource &, ResourceType::Changes)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Signal 'resourcesCreated'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resourcesPopulated'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resourceAdded'
        QtMocHelpers::SignalData<void(Resource &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'resourcePopulated'
        QtMocHelpers::SignalData<void(Resource &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'resourceToBeRemoved'
        QtMocHelpers::SignalData<void(Resource &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'resourceRemoved'
        QtMocHelpers::SignalData<void(KAlarmCal::ResourceId)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Signal 'resourceMessage'
        QtMocHelpers::SignalData<void(ResourceType::MessageType, const QString &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 }, { QMetaType::QString, 14 }, { QMetaType::QString, 15 },
        }}),
        // Signal 'eventsAdded'
        QtMocHelpers::SignalData<void(Resource &, const QList<KAEvent> &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 17, 2 },
        }}),
        // Signal 'eventUpdated'
        QtMocHelpers::SignalData<void(Resource &, const KAEvent &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 19, 2 },
        }}),
        // Signal 'eventsToBeRemoved'
        QtMocHelpers::SignalData<void(Resource &, const QList<KAEvent> &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 17, 2 },
        }}),
        // Signal 'eventsRemoved'
        QtMocHelpers::SignalData<void(Resource &, const QList<KAEvent> &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 17, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Resources, qt_meta_tag_ZN9ResourcesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Resources::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ResourcesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ResourcesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9ResourcesE_t>.metaTypes,
    nullptr
} };

void Resources::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Resources *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->settingsChanged((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ResourceType::Changes>>(_a[2]))); break;
        case 1: _t->resourcesCreated(); break;
        case 2: _t->resourcesPopulated(); break;
        case 3: _t->resourceAdded((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1]))); break;
        case 4: _t->resourcePopulated((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1]))); break;
        case 5: _t->resourceToBeRemoved((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1]))); break;
        case 6: _t->resourceRemoved((*reinterpret_cast<std::add_pointer_t<KAlarmCal::ResourceId>>(_a[1]))); break;
        case 7: _t->resourceMessage((*reinterpret_cast<std::add_pointer_t<ResourceType::MessageType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 8: _t->eventsAdded((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<KAEvent>>>(_a[2]))); break;
        case 9: _t->eventUpdated((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KAEvent>>(_a[2]))); break;
        case 10: _t->eventsToBeRemoved((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<KAEvent>>>(_a[2]))); break;
        case 11: _t->eventsRemoved((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<KAEvent>>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ResourceType::MessageType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Resources::*)(Resource & , ResourceType::Changes )>(_a, &Resources::settingsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Resources::*)()>(_a, &Resources::resourcesCreated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Resources::*)()>(_a, &Resources::resourcesPopulated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Resources::*)(Resource & )>(_a, &Resources::resourceAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Resources::*)(Resource & )>(_a, &Resources::resourcePopulated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Resources::*)(Resource & )>(_a, &Resources::resourceToBeRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Resources::*)(KAlarmCal::ResourceId )>(_a, &Resources::resourceRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Resources::*)(ResourceType::MessageType , const QString & , const QString & )>(_a, &Resources::resourceMessage, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Resources::*)(Resource & , const QList<KAEvent> & )>(_a, &Resources::eventsAdded, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Resources::*)(Resource & , const KAEvent & )>(_a, &Resources::eventUpdated, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Resources::*)(Resource & , const QList<KAEvent> & )>(_a, &Resources::eventsToBeRemoved, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Resources::*)(Resource & , const QList<KAEvent> & )>(_a, &Resources::eventsRemoved, 11))
            return;
    }
}

const QMetaObject *Resources::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Resources::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ResourcesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Resources::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Resources::settingsChanged(Resource & _t1, ResourceType::Changes _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Resources::resourcesCreated()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Resources::resourcesPopulated()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Resources::resourceAdded(Resource & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Resources::resourcePopulated(Resource & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Resources::resourceToBeRemoved(Resource & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Resources::resourceRemoved(KAlarmCal::ResourceId _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Resources::resourceMessage(ResourceType::MessageType _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 8
void Resources::eventsAdded(Resource & _t1, const QList<KAEvent> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void Resources::eventUpdated(Resource & _t1, const KAEvent & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void Resources::eventsToBeRemoved(Resource & _t1, const QList<KAEvent> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void Resources::eventsRemoved(Resource & _t1, const QList<KAEvent> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}
QT_WARNING_POP
