/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kalarm.kalarm.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KALARMADAPTOR_H
#define KALARMADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "dbushandler.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kalarm.kalarm
 */
class KalarmAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kalarm.kalarm")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kalarm.kalarm\">\n"
"    <method name=\"cancelEvent\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"eventId\"/>\n"
"    </method>\n"
"    <method name=\"triggerEvent\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"eventId\"/>\n"
"    </method>\n"
"    <method name=\"list\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"scheduleMessage\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"message\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"bgColor\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"fgColor\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"font\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"audioFile\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"reminderMins\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"recurrence\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"subRepeatInterval\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"subRepeatCount\"/>\n"
"    </method>\n"
"    <method name=\"scheduleMessage\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"message\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"bgColor\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"fgColor\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"font\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"audioFile\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"reminderMins\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurType\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurInterval\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurCount\"/>\n"
"    </method>\n"
"    <method name=\"scheduleMessage\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"message\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"bgColor\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"fgColor\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"font\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"audioFile\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"reminderMins\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurType\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurInterval\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"endDateTime\"/>\n"
"    </method>\n"
"    <method name=\"scheduleFile\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"bgColor\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"audioFile\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"reminderMins\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"recurrence\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"subRepeatInterval\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"subRepeatCount\"/>\n"
"    </method>\n"
"    <method name=\"scheduleFile\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"bgColor\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"audioFile\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"reminderMins\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurType\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurInterval\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurCount\"/>\n"
"    </method>\n"
"    <method name=\"scheduleFile\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"bgColor\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"audioFile\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"reminderMins\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurType\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurInterval\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"endDateTime\"/>\n"
"    </method>\n"
"    <method name=\"scheduleCommand\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"commandLine\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"recurrence\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"subRepeatInterval\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"subRepeatCount\"/>\n"
"    </method>\n"
"    <method name=\"scheduleCommand\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"commandLine\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurType\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurInterval\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurCount\"/>\n"
"    </method>\n"
"    <method name=\"scheduleCommand\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"commandLine\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurType\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurInterval\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"endDateTime\"/>\n"
"    </method>\n"
"    <method name=\"scheduleEmail\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"fromID\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"addresses\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"subject\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"message\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"attachments\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"recurrence\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"subRepeatInterval\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"subRepeatCount\"/>\n"
"    </method>\n"
"    <method name=\"scheduleEmail\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"fromID\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"addresses\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"subject\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"message\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"attachments\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurType\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurInterval\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurCount\"/>\n"
"    </method>\n"
"    <method name=\"scheduleEmail\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"fromID\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"addresses\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"subject\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"message\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"attachments\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurType\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurInterval\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"endDateTime\"/>\n"
"    </method>\n"
"    <method name=\"scheduleAudio\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"audioFile\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"volumePercent\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"recurrence\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"subRepeatInterval\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"subRepeatCount\"/>\n"
"    </method>\n"
"    <method name=\"scheduleAudio\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"audioFile\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"volumePercent\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurType\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurInterval\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurCount\"/>\n"
"    </method>\n"
"    <method name=\"scheduleAudio\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"audioFile\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"volumePercent\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"startDateTime\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"lateCancel\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurType\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"recurInterval\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"endDateTime\"/>\n"
"    </method>\n"
"    <method name=\"edit\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"eventID\"/>\n"
"    </method>\n"
"    <method name=\"editNew\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"type\"/>\n"
"    </method>\n"
"    <method name=\"editNew\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"templateName\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    KalarmAdaptor(DBusHandler *parent);
    ~KalarmAdaptor() override;

    inline DBusHandler *parent() const
    { return static_cast<DBusHandler *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    bool cancelEvent(const QString &eventId);
    bool edit(const QString &eventID);
    bool editNew(const QString &templateName);
    bool editNew(int type);
    QString list();
    bool scheduleAudio(const QString &audioFile, int volumePercent, const QString &startDateTime, int lateCancel, uint flags, int recurType, int recurInterval, const QString &endDateTime);
    bool scheduleAudio(const QString &audioFile, int volumePercent, const QString &startDateTime, int lateCancel, uint flags, int recurType, int recurInterval, int recurCount);
    bool scheduleAudio(const QString &audioFile, int volumePercent, const QString &startDateTime, int lateCancel, uint flags, const QString &recurrence, int subRepeatInterval, int subRepeatCount);
    bool scheduleCommand(const QString &commandLine, const QString &startDateTime, int lateCancel, uint flags, int recurType, int recurInterval, const QString &endDateTime);
    bool scheduleCommand(const QString &commandLine, const QString &startDateTime, int lateCancel, uint flags, int recurType, int recurInterval, int recurCount);
    bool scheduleCommand(const QString &commandLine, const QString &startDateTime, int lateCancel, uint flags, const QString &recurrence, int subRepeatInterval, int subRepeatCount);
    bool scheduleEmail(const QString &fromID, const QString &addresses, const QString &subject, const QString &message, const QString &attachments, const QString &startDateTime, int lateCancel, uint flags, int recurType, int recurInterval, const QString &endDateTime);
    bool scheduleEmail(const QString &fromID, const QString &addresses, const QString &subject, const QString &message, const QString &attachments, const QString &startDateTime, int lateCancel, uint flags, int recurType, int recurInterval, int recurCount);
    bool scheduleEmail(const QString &fromID, const QString &addresses, const QString &subject, const QString &message, const QString &attachments, const QString &startDateTime, int lateCancel, uint flags, const QString &recurrence, int subRepeatInterval, int subRepeatCount);
    bool scheduleFile(const QString &file, const QString &startDateTime, int lateCancel, uint flags, const QString &bgColor, const QString &audioFile, int reminderMins, int recurType, int recurInterval, const QString &endDateTime);
    bool scheduleFile(const QString &file, const QString &startDateTime, int lateCancel, uint flags, const QString &bgColor, const QString &audioFile, int reminderMins, int recurType, int recurInterval, int recurCount);
    bool scheduleFile(const QString &file, const QString &startDateTime, int lateCancel, uint flags, const QString &bgColor, const QString &audioFile, int reminderMins, const QString &recurrence, int subRepeatInterval, int subRepeatCount);
    bool scheduleMessage(const QString &message, const QString &startDateTime, int lateCancel, uint flags, const QString &bgColor, const QString &fgColor, const QString &font, const QString &audioFile, int reminderMins, int recurType, int recurInterval, const QString &endDateTime);
    bool scheduleMessage(const QString &message, const QString &startDateTime, int lateCancel, uint flags, const QString &bgColor, const QString &fgColor, const QString &font, const QString &audioFile, int reminderMins, int recurType, int recurInterval, int recurCount);
    bool scheduleMessage(const QString &message, const QString &startDateTime, int lateCancel, uint flags, const QString &bgColor, const QString &fgColor, const QString &font, const QString &audioFile, int reminderMins, const QString &recurrence, int subRepeatInterval, int subRepeatCount);
    bool triggerEvent(const QString &eventId);
Q_SIGNALS: // SIGNALS
};

#endif
