/****************************************************************************
** Meta object code from reading C++ file 'prefdlg_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/prefdlg_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'prefdlg_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12PrefsTabBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto PrefsTabBase::qt_create_metaobjectdata<qt_meta_tag_ZN12PrefsTabBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PrefsTabBase"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PrefsTabBase, qt_meta_tag_ZN12PrefsTabBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PrefsTabBase::staticMetaObject = { {
    QMetaObject::SuperData::link<StackedScrollWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PrefsTabBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PrefsTabBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12PrefsTabBaseE_t>.metaTypes,
    nullptr
} };

void PrefsTabBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PrefsTabBase *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *PrefsTabBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PrefsTabBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PrefsTabBaseE_t>.strings))
        return static_cast<void*>(this);
    return StackedScrollWidget::qt_metacast(_clname);
}

int PrefsTabBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = StackedScrollWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN11MiscPrefTabE_t {};
} // unnamed namespace

template <> constexpr inline auto MiscPrefTab::qt_create_metaobjectdata<qt_meta_tag_ZN11MiscPrefTabE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MiscPrefTab",
        "slotRunModeChanged",
        "",
        "QAbstractButton*",
        "old",
        "now",
        "slotOtherTerminalToggled"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotRunModeChanged'
        QtMocHelpers::SlotData<void(QAbstractButton *, QAbstractButton *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
        // Slot 'slotOtherTerminalToggled'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MiscPrefTab, qt_meta_tag_ZN11MiscPrefTabE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MiscPrefTab::staticMetaObject = { {
    QMetaObject::SuperData::link<PrefsTabBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MiscPrefTabE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MiscPrefTabE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11MiscPrefTabE_t>.metaTypes,
    nullptr
} };

void MiscPrefTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MiscPrefTab *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotRunModeChanged((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[2]))); break;
        case 1: _t->slotOtherTerminalToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *MiscPrefTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MiscPrefTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MiscPrefTabE_t>.strings))
        return static_cast<void*>(this);
    return PrefsTabBase::qt_metacast(_clname);
}

int MiscPrefTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PrefsTabBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN11TimePrefTabE_t {};
} // unnamed namespace

template <> constexpr inline auto TimePrefTab::qt_create_metaobjectdata<qt_meta_tag_ZN11TimePrefTabE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TimePrefTab"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TimePrefTab, qt_meta_tag_ZN11TimePrefTabE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TimePrefTab::staticMetaObject = { {
    QMetaObject::SuperData::link<PrefsTabBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TimePrefTabE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TimePrefTabE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11TimePrefTabE_t>.metaTypes,
    nullptr
} };

void TimePrefTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TimePrefTab *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *TimePrefTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TimePrefTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TimePrefTabE_t>.strings))
        return static_cast<void*>(this);
    return PrefsTabBase::qt_metacast(_clname);
}

int TimePrefTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PrefsTabBase::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN12StorePrefTabE_t {};
} // unnamed namespace

template <> constexpr inline auto StorePrefTab::qt_create_metaobjectdata<qt_meta_tag_ZN12StorePrefTabE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StorePrefTab",
        "slotArchivedToggled",
        "",
        "slotClearArchived"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotArchivedToggled'
        QtMocHelpers::SlotData<void(bool)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotClearArchived'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StorePrefTab, qt_meta_tag_ZN12StorePrefTabE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject StorePrefTab::staticMetaObject = { {
    QMetaObject::SuperData::link<PrefsTabBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12StorePrefTabE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12StorePrefTabE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12StorePrefTabE_t>.metaTypes,
    nullptr
} };

void StorePrefTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StorePrefTab *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotArchivedToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->slotClearArchived(); break;
        default: ;
        }
    }
}

const QMetaObject *StorePrefTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StorePrefTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12StorePrefTabE_t>.strings))
        return static_cast<void*>(this);
    return PrefsTabBase::qt_metacast(_clname);
}

int StorePrefTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PrefsTabBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN12EmailPrefTabE_t {};
} // unnamed namespace

template <> constexpr inline auto EmailPrefTab::qt_create_metaobjectdata<qt_meta_tag_ZN12EmailPrefTabE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EmailPrefTab",
        "slotEmailClientChanged",
        "",
        "QAbstractButton*",
        "slotFromAddrChanged",
        "slotBccAddrChanged",
        "slotAddressChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotEmailClientChanged'
        QtMocHelpers::SlotData<void(QAbstractButton *, QAbstractButton *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 3, 2 },
        }}),
        // Slot 'slotFromAddrChanged'
        QtMocHelpers::SlotData<void(QAbstractButton *, QAbstractButton *)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 3, 2 },
        }}),
        // Slot 'slotBccAddrChanged'
        QtMocHelpers::SlotData<void(QAbstractButton *, QAbstractButton *)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 3, 2 },
        }}),
        // Slot 'slotAddressChanged'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EmailPrefTab, qt_meta_tag_ZN12EmailPrefTabE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EmailPrefTab::staticMetaObject = { {
    QMetaObject::SuperData::link<PrefsTabBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12EmailPrefTabE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12EmailPrefTabE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12EmailPrefTabE_t>.metaTypes,
    nullptr
} };

void EmailPrefTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EmailPrefTab *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotEmailClientChanged((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[2]))); break;
        case 1: _t->slotFromAddrChanged((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[2]))); break;
        case 2: _t->slotBccAddrChanged((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[2]))); break;
        case 3: _t->slotAddressChanged(); break;
        default: ;
        }
    }
}

const QMetaObject *EmailPrefTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EmailPrefTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12EmailPrefTabE_t>.strings))
        return static_cast<void*>(this);
    return PrefsTabBase::qt_metacast(_clname);
}

int EmailPrefTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PrefsTabBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN11EditPrefTabE_t {};
} // unnamed namespace

template <> constexpr inline auto EditPrefTab::qt_create_metaobjectdata<qt_meta_tag_ZN11EditPrefTabE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EditPrefTab",
        "slotBrowseSoundFile",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotBrowseSoundFile'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditPrefTab, qt_meta_tag_ZN11EditPrefTabE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EditPrefTab::staticMetaObject = { {
    QMetaObject::SuperData::link<PrefsTabBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11EditPrefTabE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11EditPrefTabE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11EditPrefTabE_t>.metaTypes,
    nullptr
} };

void EditPrefTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditPrefTab *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotBrowseSoundFile(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *EditPrefTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EditPrefTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11EditPrefTabE_t>.strings))
        return static_cast<void*>(this);
    return PrefsTabBase::qt_metacast(_clname);
}

int EditPrefTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PrefsTabBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN11ViewPrefTabE_t {};
} // unnamed namespace

template <> constexpr inline auto ViewPrefTab::qt_create_metaobjectdata<qt_meta_tag_ZN11ViewPrefTabE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ViewPrefTab",
        "slotTooltipAlarmsToggled",
        "",
        "slotTooltipMaxToggled",
        "slotTooltipTimeToggled",
        "slotTooltipTimeToToggled",
        "slotAutoHideSysTrayChanged",
        "QAbstractButton*",
        "slotWindowPosChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotTooltipAlarmsToggled'
        QtMocHelpers::SlotData<void(bool)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotTooltipMaxToggled'
        QtMocHelpers::SlotData<void(bool)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotTooltipTimeToggled'
        QtMocHelpers::SlotData<void(bool)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotTooltipTimeToToggled'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotAutoHideSysTrayChanged'
        QtMocHelpers::SlotData<void(QAbstractButton *, QAbstractButton *)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 }, { 0x80000000 | 7, 2 },
        }}),
        // Slot 'slotWindowPosChanged'
        QtMocHelpers::SlotData<void(QAbstractButton *, QAbstractButton *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 }, { 0x80000000 | 7, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ViewPrefTab, qt_meta_tag_ZN11ViewPrefTabE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ViewPrefTab::staticMetaObject = { {
    QMetaObject::SuperData::link<PrefsTabBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ViewPrefTabE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ViewPrefTabE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ViewPrefTabE_t>.metaTypes,
    nullptr
} };

void ViewPrefTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ViewPrefTab *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotTooltipAlarmsToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->slotTooltipMaxToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->slotTooltipTimeToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->slotTooltipTimeToToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->slotAutoHideSysTrayChanged((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[2]))); break;
        case 5: _t->slotWindowPosChanged((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *ViewPrefTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ViewPrefTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ViewPrefTabE_t>.strings))
        return static_cast<void*>(this);
    return PrefsTabBase::qt_metacast(_clname);
}

int ViewPrefTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PrefsTabBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
