/****************************************************************************
** Meta object code from reading C++ file 'editdlgtypes.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/editdlgtypes.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'editdlgtypes.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19EditDisplayAlarmDlgE_t {};
} // unnamed namespace

template <> constexpr inline auto EditDisplayAlarmDlg::qt_create_metaobjectdata<qt_meta_tag_ZN19EditDisplayAlarmDlgE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EditDisplayAlarmDlg",
        "slotAlarmTypeChanged",
        "",
        "index",
        "slotDisplayMethodChanged",
        "slotPickFile",
        "slotCmdScriptToggled",
        "setColours",
        "QColor",
        "fg",
        "bg"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotAlarmTypeChanged'
        QtMocHelpers::SlotData<void(int)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'slotDisplayMethodChanged'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'slotPickFile'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCmdScriptToggled'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setColours'
        QtMocHelpers::SlotData<void(const QColor &, const QColor &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 8, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditDisplayAlarmDlg, qt_meta_tag_ZN19EditDisplayAlarmDlgE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EditDisplayAlarmDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<EditAlarmDlg::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19EditDisplayAlarmDlgE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19EditDisplayAlarmDlgE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19EditDisplayAlarmDlgE_t>.metaTypes,
    nullptr
} };

void EditDisplayAlarmDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditDisplayAlarmDlg *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotAlarmTypeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->slotDisplayMethodChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->slotPickFile(); break;
        case 3: _t->slotCmdScriptToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->setColours((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *EditDisplayAlarmDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EditDisplayAlarmDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19EditDisplayAlarmDlgE_t>.strings))
        return static_cast<void*>(this);
    return EditAlarmDlg::qt_metacast(_clname);
}

int EditDisplayAlarmDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EditAlarmDlg::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN19EditCommandAlarmDlgE_t {};
} // unnamed namespace

template <> constexpr inline auto EditCommandAlarmDlg::qt_create_metaobjectdata<qt_meta_tag_ZN19EditCommandAlarmDlgE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EditCommandAlarmDlg",
        "slotCmdScriptToggled",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotCmdScriptToggled'
        QtMocHelpers::SlotData<void(bool)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditCommandAlarmDlg, qt_meta_tag_ZN19EditCommandAlarmDlgE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EditCommandAlarmDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<EditAlarmDlg::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19EditCommandAlarmDlgE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19EditCommandAlarmDlgE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19EditCommandAlarmDlgE_t>.metaTypes,
    nullptr
} };

void EditCommandAlarmDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditCommandAlarmDlg *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotCmdScriptToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *EditCommandAlarmDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EditCommandAlarmDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19EditCommandAlarmDlgE_t>.strings))
        return static_cast<void*>(this);
    return EditAlarmDlg::qt_metacast(_clname);
}

int EditCommandAlarmDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EditAlarmDlg::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN17EditEmailAlarmDlgE_t {};
} // unnamed namespace

template <> constexpr inline auto EditEmailAlarmDlg::qt_create_metaobjectdata<qt_meta_tag_ZN17EditEmailAlarmDlgE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EditEmailAlarmDlg",
        "slotTrySuccess",
        "",
        "openAddressBook",
        "slotAddAttachment",
        "slotRemoveAttachment"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotTrySuccess'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openAddressBook'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddAttachment'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveAttachment'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditEmailAlarmDlg, qt_meta_tag_ZN17EditEmailAlarmDlgE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EditEmailAlarmDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<EditAlarmDlg::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17EditEmailAlarmDlgE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17EditEmailAlarmDlgE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17EditEmailAlarmDlgE_t>.metaTypes,
    nullptr
} };

void EditEmailAlarmDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditEmailAlarmDlg *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotTrySuccess(); break;
        case 1: _t->openAddressBook(); break;
        case 2: _t->slotAddAttachment(); break;
        case 3: _t->slotRemoveAttachment(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *EditEmailAlarmDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EditEmailAlarmDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17EditEmailAlarmDlgE_t>.strings))
        return static_cast<void*>(this);
    return EditAlarmDlg::qt_metacast(_clname);
}

int EditEmailAlarmDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EditAlarmDlg::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN17EditAudioAlarmDlgE_t {};
} // unnamed namespace

template <> constexpr inline auto EditAudioAlarmDlg::qt_create_metaobjectdata<qt_meta_tag_ZN17EditAudioAlarmDlgE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EditAudioAlarmDlg",
        "slotTry",
        "",
        "audioWinDestroyed",
        "slotAudioPlaying",
        "playing"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotTry'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'audioWinDestroyed'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAudioPlaying'
        QtMocHelpers::SlotData<void(bool)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditAudioAlarmDlg, qt_meta_tag_ZN17EditAudioAlarmDlgE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EditAudioAlarmDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<EditAlarmDlg::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17EditAudioAlarmDlgE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17EditAudioAlarmDlgE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17EditAudioAlarmDlgE_t>.metaTypes,
    nullptr
} };

void EditAudioAlarmDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditAudioAlarmDlg *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotTry(); break;
        case 1: _t->audioWinDestroyed(); break;
        case 2: _t->slotAudioPlaying((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *EditAudioAlarmDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EditAudioAlarmDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17EditAudioAlarmDlgE_t>.strings))
        return static_cast<void*>(this);
    return EditAlarmDlg::qt_metacast(_clname);
}

int EditAudioAlarmDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EditAlarmDlg::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
