/****************************************************************************
** Meta object code from reading C++ file 'fileresourcedatamodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/resources/fileresourcedatamodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fileresourcedatamodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21FileResourceDataModelE_t {};
} // unnamed namespace

template <> constexpr inline auto FileResourceDataModel::qt_create_metaobjectdata<qt_meta_tag_ZN21FileResourceDataModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FileResourceDataModel",
        "haveEventsStatus",
        "",
        "have",
        "slotMigrationCompleted",
        "slotUpdateTimeTo",
        "slotUpdateArchivedColour",
        "QColor",
        "slotUpdateDisabledColour",
        "slotUpdateHolidays",
        "slotUpdateWorkingHours",
        "addResource",
        "Resource&",
        "slotResourceLoaded",
        "slotResourceSettingsChanged",
        "ResourceType::Changes",
        "removeResource",
        "slotEventsAdded",
        "QList<KAEvent>",
        "slotEventUpdated",
        "KAEvent",
        "deleteEvents",
        "slotResourceMessage",
        "ResourceType::MessageType",
        "message",
        "details"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'haveEventsStatus'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Slot 'slotMigrationCompleted'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateTimeTo'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateArchivedColour'
        QtMocHelpers::SlotData<void(const QColor &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'slotUpdateDisabledColour'
        QtMocHelpers::SlotData<void(const QColor &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'slotUpdateHolidays'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateWorkingHours'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addResource'
        QtMocHelpers::SlotData<void(Resource &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Slot 'slotResourceLoaded'
        QtMocHelpers::SlotData<void(Resource &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Slot 'slotResourceSettingsChanged'
        QtMocHelpers::SlotData<void(Resource &, ResourceType::Changes)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 2 }, { 0x80000000 | 15, 2 },
        }}),
        // Slot 'removeResource'
        QtMocHelpers::SlotData<void(Resource &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Slot 'slotEventsAdded'
        QtMocHelpers::SlotData<void(Resource &, const QList<KAEvent> &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 2 }, { 0x80000000 | 18, 2 },
        }}),
        // Slot 'slotEventUpdated'
        QtMocHelpers::SlotData<void(Resource &, const KAEvent &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 2 }, { 0x80000000 | 20, 2 },
        }}),
        // Slot 'deleteEvents'
        QtMocHelpers::SlotData<bool(Resource &, const QList<KAEvent> &)>(21, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 12, 2 }, { 0x80000000 | 18, 2 },
        }}),
        // Slot 'slotResourceMessage'
        QtMocHelpers::SlotData<void(ResourceType::MessageType, const QString &, const QString &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 2 }, { QMetaType::QString, 24 }, { QMetaType::QString, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileResourceDataModel, qt_meta_tag_ZN21FileResourceDataModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FileResourceDataModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21FileResourceDataModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21FileResourceDataModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21FileResourceDataModelE_t>.metaTypes,
    nullptr
} };

void FileResourceDataModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileResourceDataModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->haveEventsStatus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->slotMigrationCompleted(); break;
        case 2: _t->slotUpdateTimeTo(); break;
        case 3: _t->slotUpdateArchivedColour((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 4: _t->slotUpdateDisabledColour((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 5: _t->slotUpdateHolidays(); break;
        case 6: _t->slotUpdateWorkingHours(); break;
        case 7: _t->addResource((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1]))); break;
        case 8: _t->slotResourceLoaded((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1]))); break;
        case 9: _t->slotResourceSettingsChanged((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ResourceType::Changes>>(_a[2]))); break;
        case 10: _t->removeResource((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1]))); break;
        case 11: _t->slotEventsAdded((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<KAEvent>>>(_a[2]))); break;
        case 12: _t->slotEventUpdated((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KAEvent>>(_a[2]))); break;
        case 13: { bool _r = _t->deleteEvents((*reinterpret_cast<std::add_pointer_t<Resource&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<KAEvent>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->slotResourceMessage((*reinterpret_cast<std::add_pointer_t<ResourceType::MessageType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ResourceType::MessageType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileResourceDataModel::*)(bool )>(_a, &FileResourceDataModel::haveEventsStatus, 0))
            return;
    }
}

const QMetaObject *FileResourceDataModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FileResourceDataModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21FileResourceDataModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ResourceDataModelBase"))
        return static_cast< ResourceDataModelBase*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int FileResourceDataModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void FileResourceDataModel::haveEventsStatus(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
