/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/mainwindow.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWindow",
        "selectionChanged",
        "",
        "slotInitHamburgerMenu",
        "slotNew",
        "EditAlarmDlg::Type",
        "slotNewFromTemplate",
        "KAlarmCal::KAEvent",
        "slotNewTemplate",
        "slotCopy",
        "slotModify",
        "slotDeleteIf",
        "slotDeleteForce",
        "slotReactivate",
        "slotEnable",
        "slotSkip",
        "slotToggleTrayIcon",
        "slotRefreshAlarms",
        "slotImportAlarms",
        "slotExportAlarms",
        "slotBirthdays",
        "slotTemplates",
        "slotTemplatesEnd",
        "slotPreferences",
        "slotToggleMenubar",
        "dontShowWarning",
        "slotConfigureKeys",
        "slotConfigureNotifications",
        "slotConfigureToolbar",
        "slotNewToolbarConfig",
        "slotQuit",
        "slotSelection",
        "slotContextMenuRequested",
        "QPoint",
        "globalPos",
        "slotShowArchived",
        "slotSpreadWindowsShortcut",
        "slotWakeFromSuspend",
        "updateKeepArchived",
        "days",
        "slotUndo",
        "slotUndoItem",
        "QAction*",
        "id",
        "slotRedo",
        "slotRedoItem",
        "slotInitUndoMenu",
        "slotInitRedoMenu",
        "slotUndoStatus",
        "slotFindActive",
        "updateTrayIconAction",
        "slotToggleResourceSelector",
        "slotToggleDateNavigator",
        "slotCalendarStatusChanged",
        "slotAlarmListColumnsChanged",
        "datesSelected",
        "QList<QDate>",
        "dates",
        "workChange",
        "resourcesResized",
        "showMenuErrorMessage",
        "showErrorMessage",
        "editAlarmOk",
        "editAlarmDeleted",
        "deferAlarmDlgDone",
        "result",
        "deferAlarmDlgDeleted",
        "obj"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInitHamburgerMenu'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNew'
        QtMocHelpers::SlotData<void(EditAlarmDlg::Type)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'slotNewFromTemplate'
        QtMocHelpers::SlotData<void(const KAlarmCal::KAEvent &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'slotNewTemplate'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCopy'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotModify'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteIf'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteForce'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReactivate'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEnable'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSkip'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToggleTrayIcon'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRefreshAlarms'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotImportAlarms'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExportAlarms'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotBirthdays'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTemplates'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTemplatesEnd'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPreferences'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToggleMenubar'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'slotConfigureKeys'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotConfigureNotifications'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotConfigureToolbar'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewToolbarConfig'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotQuit'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelection'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'slotShowArchived'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSpreadWindowsShortcut'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotWakeFromSuspend'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateKeepArchived'
        QtMocHelpers::SlotData<void(int)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'slotUndo'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUndoItem'
        QtMocHelpers::SlotData<void(QAction *)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'slotRedo'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRedoItem'
        QtMocHelpers::SlotData<void(QAction *)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'slotInitUndoMenu'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotInitRedoMenu'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUndoStatus'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'slotFindActive'
        QtMocHelpers::SlotData<void(bool)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'updateTrayIconAction'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToggleResourceSelector'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToggleDateNavigator'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCalendarStatusChanged'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAlarmListColumnsChanged'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'datesSelected'
        QtMocHelpers::SlotData<void(const QList<QDate> &, bool)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 56, 57 }, { QMetaType::Bool, 58 },
        }}),
        // Slot 'resourcesResized'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showMenuErrorMessage'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showErrorMessage'
        QtMocHelpers::SlotData<void(const QString &)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'editAlarmOk'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editAlarmDeleted'
        QtMocHelpers::SlotData<void(QObject *)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 2 },
        }}),
        // Slot 'deferAlarmDlgDone'
        QtMocHelpers::SlotData<void(int)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 65 },
        }}),
        // Slot 'deferAlarmDlgDeleted'
        QtMocHelpers::SlotData<void(QObject *)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 67 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<MainWindowBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MainWindowE_t>.metaTypes,
    nullptr
} };

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectionChanged(); break;
        case 1: _t->slotInitHamburgerMenu(); break;
        case 2: _t->slotNew((*reinterpret_cast<std::add_pointer_t<EditAlarmDlg::Type>>(_a[1]))); break;
        case 3: _t->slotNewFromTemplate((*reinterpret_cast<std::add_pointer_t<KAlarmCal::KAEvent>>(_a[1]))); break;
        case 4: _t->slotNewTemplate(); break;
        case 5: _t->slotCopy(); break;
        case 6: _t->slotModify(); break;
        case 7: _t->slotDeleteIf(); break;
        case 8: _t->slotDeleteForce(); break;
        case 9: _t->slotReactivate(); break;
        case 10: _t->slotEnable(); break;
        case 11: _t->slotSkip(); break;
        case 12: _t->slotToggleTrayIcon(); break;
        case 13: _t->slotRefreshAlarms(); break;
        case 14: _t->slotImportAlarms(); break;
        case 15: _t->slotExportAlarms(); break;
        case 16: _t->slotBirthdays(); break;
        case 17: _t->slotTemplates(); break;
        case 18: _t->slotTemplatesEnd(); break;
        case 19: _t->slotPreferences(); break;
        case 20: _t->slotToggleMenubar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->slotConfigureKeys(); break;
        case 22: _t->slotConfigureNotifications(); break;
        case 23: _t->slotConfigureToolbar(); break;
        case 24: _t->slotNewToolbarConfig(); break;
        case 25: _t->slotQuit(); break;
        case 26: _t->slotSelection(); break;
        case 27: _t->slotContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 28: _t->slotShowArchived(); break;
        case 29: _t->slotSpreadWindowsShortcut(); break;
        case 30: _t->slotWakeFromSuspend(); break;
        case 31: _t->updateKeepArchived((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->slotUndo(); break;
        case 33: _t->slotUndoItem((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 34: _t->slotRedo(); break;
        case 35: _t->slotRedoItem((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 36: _t->slotInitUndoMenu(); break;
        case 37: _t->slotInitRedoMenu(); break;
        case 38: _t->slotUndoStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 39: _t->slotFindActive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: _t->updateTrayIconAction(); break;
        case 41: _t->slotToggleResourceSelector(); break;
        case 42: _t->slotToggleDateNavigator(); break;
        case 43: _t->slotCalendarStatusChanged(); break;
        case 44: _t->slotAlarmListColumnsChanged(); break;
        case 45: _t->datesSelected((*reinterpret_cast<std::add_pointer_t<QList<QDate>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 46: _t->resourcesResized(); break;
        case 47: _t->showMenuErrorMessage(); break;
        case 48: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 49: _t->editAlarmOk(); break;
        case 50: _t->editAlarmDeleted((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 51: _t->deferAlarmDlgDone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 52: _t->deferAlarmDlgDeleted((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KAlarmCal::KAEvent >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 45:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDate> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::selectionChanged, 0))
            return;
    }
}

const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KCalendarCore::Calendar::CalendarObserver"))
        return static_cast< KCalendarCore::Calendar::CalendarObserver*>(this);
    return MainWindowBase::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MainWindowBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 53)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 53;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 53)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 53;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
