// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "kalarm_autostart_debug.h"


Q_LOGGING_CATEGORY(KALARMAUTOSTART_LOG, "org.kde.pim.autostart_kalarm", QtInfoMsg)

