/****************************************************************************
** Meta object code from reading C++ file 'pluginbaseakonadi.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalarm-26.04.0/src/pluginbaseakonadi.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pluginbaseakonadi.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17PluginBaseAkonadiE_t {};
} // unnamed namespace

template <> constexpr inline auto PluginBaseAkonadi::qt_create_metaobjectdata<qt_meta_tag_ZN17PluginBaseAkonadiE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PluginBaseAkonadi",
        "birthdayModelDataChanged",
        "",
        "emailSent",
        "MailSend::JobData",
        "errmsgs",
        "sendError",
        "emailQueued",
        "KAlarmCal::KAEvent",
        "akonadiMigrationComplete",
        "migrated",
        "migrateFileResource",
        "resourceName",
        "QUrl",
        "location",
        "KAlarmCal::CalEvent::Types",
        "alarmTypes",
        "displayName",
        "QColor",
        "backgroundColour",
        "enabledTypes",
        "standardTypes",
        "readOnly",
        "migrateDirResource",
        "path"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'birthdayModelDataChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emailSent'
        QtMocHelpers::SignalData<void(const MailSend::JobData &, const QStringList &, bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { QMetaType::QStringList, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'emailQueued'
        QtMocHelpers::SignalData<void(const KAlarmCal::KAEvent &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'akonadiMigrationComplete'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Signal 'migrateFileResource'
        QtMocHelpers::SignalData<void(const QString &, const QUrl &, KAlarmCal::CalEvent::Types, const QString &, const QColor &, KAlarmCal::CalEvent::Types, KAlarmCal::CalEvent::Types, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
            { 0x80000000 | 18, 19 }, { 0x80000000 | 15, 20 }, { 0x80000000 | 15, 21 }, { QMetaType::Bool, 22 },
        }}),
        // Signal 'migrateDirResource'
        QtMocHelpers::SignalData<void(const QString &, const QString &, KAlarmCal::CalEvent::Types, const QString &, const QColor &, KAlarmCal::CalEvent::Types, KAlarmCal::CalEvent::Types, bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 24 }, { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
            { 0x80000000 | 18, 19 }, { 0x80000000 | 15, 20 }, { 0x80000000 | 15, 21 }, { QMetaType::Bool, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PluginBaseAkonadi, qt_meta_tag_ZN17PluginBaseAkonadiE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PluginBaseAkonadi::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PluginBaseAkonadiE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PluginBaseAkonadiE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17PluginBaseAkonadiE_t>.metaTypes,
    nullptr
} };

void PluginBaseAkonadi::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PluginBaseAkonadi *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->birthdayModelDataChanged(); break;
        case 1: _t->emailSent((*reinterpret_cast<std::add_pointer_t<MailSend::JobData>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 2: _t->emailQueued((*reinterpret_cast<std::add_pointer_t<KAlarmCal::KAEvent>>(_a[1]))); break;
        case 3: _t->akonadiMigrationComplete((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->migrateFileResource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KAlarmCal::CalEvent::Types>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KAlarmCal::CalEvent::Types>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<KAlarmCal::CalEvent::Types>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8]))); break;
        case 5: _t->migrateDirResource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KAlarmCal::CalEvent::Types>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KAlarmCal::CalEvent::Types>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<KAlarmCal::CalEvent::Types>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PluginBaseAkonadi::*)()>(_a, &PluginBaseAkonadi::birthdayModelDataChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginBaseAkonadi::*)(const MailSend::JobData & , const QStringList & , bool )>(_a, &PluginBaseAkonadi::emailSent, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginBaseAkonadi::*)(const KAlarmCal::KAEvent & )>(_a, &PluginBaseAkonadi::emailQueued, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginBaseAkonadi::*)(bool )>(_a, &PluginBaseAkonadi::akonadiMigrationComplete, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginBaseAkonadi::*)(const QString & , const QUrl & , KAlarmCal::CalEvent::Types , const QString & , const QColor & , KAlarmCal::CalEvent::Types , KAlarmCal::CalEvent::Types , bool )>(_a, &PluginBaseAkonadi::migrateFileResource, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginBaseAkonadi::*)(const QString & , const QString & , KAlarmCal::CalEvent::Types , const QString & , const QColor & , KAlarmCal::CalEvent::Types , KAlarmCal::CalEvent::Types , bool )>(_a, &PluginBaseAkonadi::migrateDirResource, 5))
            return;
    }
}

const QMetaObject *PluginBaseAkonadi::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginBaseAkonadi::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PluginBaseAkonadiE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PluginBaseAkonadi::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void PluginBaseAkonadi::birthdayModelDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PluginBaseAkonadi::emailSent(const MailSend::JobData & _t1, const QStringList & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void PluginBaseAkonadi::emailQueued(const KAlarmCal::KAEvent & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PluginBaseAkonadi::akonadiMigrationComplete(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PluginBaseAkonadi::migrateFileResource(const QString & _t1, const QUrl & _t2, KAlarmCal::CalEvent::Types _t3, const QString & _t4, const QColor & _t5, KAlarmCal::CalEvent::Types _t6, KAlarmCal::CalEvent::Types _t7, bool _t8)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8);
}

// SIGNAL 5
void PluginBaseAkonadi::migrateDirResource(const QString & _t1, const QString & _t2, KAlarmCal::CalEvent::Types _t3, const QString & _t4, const QColor & _t5, KAlarmCal::CalEvent::Types _t6, KAlarmCal::CalEvent::Types _t7, bool _t8)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8);
}
QT_WARNING_POP
