/****************************************************************************
** Meta object code from reading C++ file 'kalarmconfig.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../kalarmconfig.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kalarmconfig.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15PreferencesBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto PreferencesBase::qt_create_metaobjectdata<qt_meta_tag_ZN15PreferencesBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PreferencesBase",
        "showInSystemTrayChanged",
        "",
        "ShowInSystemTray",
        "autoHideSystemTrayChanged",
        "Base_AutoHideSystemTray",
        "base_TimeZoneChanged",
        "Base_TimeZone",
        "base_HolidayRegionChanged",
        "Base_HolidayRegion",
        "base_StartOfDayChanged",
        "Base_StartOfDay",
        "base_WorkTimeChanged",
        "Base_WorkDayStart",
        "Base_WorkDayEnd",
        "Base_WorkDays",
        "useAlarmNameChanged",
        "UseAlarmName",
        "messageFontChanged",
        "QFont",
        "MessageFont",
        "disabledColourChanged",
        "QColor",
        "DisabledColour",
        "archivedColourChanged",
        "ArchivedColour",
        "archivedKeepDaysChanged",
        "ArchivedKeepDays",
        "wakeFromSuspendAdvanceChanged",
        "WakeFromSuspendAdvance",
        "feb29TypeChanged",
        "Feb29Type",
        "DefaultFeb29Type",
        "tooltipPreferencesChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showInSystemTrayChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'autoHideSystemTrayChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'base_TimeZoneChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'base_HolidayRegionChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'base_StartOfDayChanged'
        QtMocHelpers::SignalData<void(const QDateTime &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 11 },
        }}),
        // Signal 'base_WorkTimeChanged'
        QtMocHelpers::SignalData<void(const QDateTime &, const QDateTime &, int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 13 }, { QMetaType::QDateTime, 14 }, { QMetaType::Int, 15 },
        }}),
        // Signal 'useAlarmNameChanged'
        QtMocHelpers::SignalData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'messageFontChanged'
        QtMocHelpers::SignalData<void(const QFont &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'disabledColourChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Signal 'archivedColourChanged'
        QtMocHelpers::SignalData<void(const QColor &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 25 },
        }}),
        // Signal 'archivedKeepDaysChanged'
        QtMocHelpers::SignalData<void(int)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Signal 'wakeFromSuspendAdvanceChanged'
        QtMocHelpers::SignalData<void(uint)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 29 },
        }}),
        // Signal 'feb29TypeChanged'
        QtMocHelpers::SignalData<void(enum Feb29Type)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Signal 'tooltipPreferencesChanged'
        QtMocHelpers::SignalData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PreferencesBase, qt_meta_tag_ZN15PreferencesBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PreferencesBase::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PreferencesBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PreferencesBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15PreferencesBaseE_t>.metaTypes,
    nullptr
} };

void PreferencesBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PreferencesBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showInSystemTrayChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->autoHideSystemTrayChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->base_TimeZoneChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->base_HolidayRegionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->base_StartOfDayChanged((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 5: _t->base_WorkTimeChanged((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->useAlarmNameChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->messageFontChanged((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 8: _t->disabledColourChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 9: _t->archivedColourChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 10: _t->archivedKeepDaysChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->wakeFromSuspendAdvanceChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 12: _t->feb29TypeChanged((*reinterpret_cast<std::add_pointer_t<enum Feb29Type>>(_a[1]))); break;
        case 13: _t->tooltipPreferencesChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PreferencesBase::*)(bool )>(_a, &PreferencesBase::showInSystemTrayChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesBase::*)(int )>(_a, &PreferencesBase::autoHideSystemTrayChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesBase::*)(const QString & )>(_a, &PreferencesBase::base_TimeZoneChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesBase::*)(const QString & )>(_a, &PreferencesBase::base_HolidayRegionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesBase::*)(const QDateTime & )>(_a, &PreferencesBase::base_StartOfDayChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesBase::*)(const QDateTime & , const QDateTime & , int )>(_a, &PreferencesBase::base_WorkTimeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesBase::*)(bool )>(_a, &PreferencesBase::useAlarmNameChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesBase::*)(const QFont & )>(_a, &PreferencesBase::messageFontChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesBase::*)(const QColor & )>(_a, &PreferencesBase::disabledColourChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesBase::*)(const QColor & )>(_a, &PreferencesBase::archivedColourChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesBase::*)(int )>(_a, &PreferencesBase::archivedKeepDaysChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesBase::*)(uint )>(_a, &PreferencesBase::wakeFromSuspendAdvanceChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesBase::*)(Feb29Type )>(_a, &PreferencesBase::feb29TypeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (PreferencesBase::*)()>(_a, &PreferencesBase::tooltipPreferencesChanged, 13))
            return;
    }
}

const QMetaObject *PreferencesBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PreferencesBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PreferencesBaseE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int PreferencesBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void PreferencesBase::showInSystemTrayChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PreferencesBase::autoHideSystemTrayChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PreferencesBase::base_TimeZoneChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PreferencesBase::base_HolidayRegionChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PreferencesBase::base_StartOfDayChanged(const QDateTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PreferencesBase::base_WorkTimeChanged(const QDateTime & _t1, const QDateTime & _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void PreferencesBase::useAlarmNameChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void PreferencesBase::messageFontChanged(const QFont & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void PreferencesBase::disabledColourChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void PreferencesBase::archivedColourChanged(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void PreferencesBase::archivedKeepDaysChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void PreferencesBase::wakeFromSuspendAdvanceChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void PreferencesBase::feb29TypeChanged(Feb29Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void PreferencesBase::tooltipPreferencesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
